SimpleAuthProvider

Struct SimpleAuthProvider 

pub struct SimpleAuthProvider { /* private fields */ }
Simple authentication provider that holds credentials directly in memory

This is the Rust equivalent of TypeScript SDK’s SimpleAuthenticationDetailsProvider. It provides a straightforward way to create an authentication provider with credentials provided directly, without reading from configuration files.

Example

use oci_rust_sdk::auth::{SimpleAuthProvider, SimpleAuthProviderRequiredFields};
use oci_rust_sdk::core::Region;

let required = SimpleAuthProviderRequiredFields {
    tenancy: "ocid1.tenancy.oc1..aaa...".to_string(),
    user: "ocid1.user.oc1..aaa...".to_string(),
    fingerprint: "aa:bb:cc:dd:ee:ff:00:11:22:33:44:55:66:77:88:99".to_string(),
    private_key: "-----BEGIN RSA PRIVATE KEY-----\n...".to_string(),
};

let provider = SimpleAuthProvider::builder(required)
    .region(Region::ApSeoul1)
    .build();

Implementations

Source

impl SimpleAuthProvider

pub fn new( tenancy: impl Into<String>, user: impl Into<String>, fingerprint: impl Into<String>, private_key: impl Into<String>, ) -> Self

Create a new SimpleAuthProvider with required fields

Arguments
  • tenancy - Tenancy OCID
  • user - User OCID
  • fingerprint - Public key fingerprint
  • private_key - Private key in PEM format
pub fn builder( required: SimpleAuthProviderRequiredFields, ) -> SimpleAuthProviderBuilder

Create a builder for constructing a SimpleAuthProvider

pub fn tenancy(&self) -> &str

Get the tenancy OCID

pub fn user(&self) -> &str

Get the user OCID

pub fn fingerprint(&self) -> &str

Get the fingerprint

pub fn region(&self) -> Option<Region>

Get the region (if set)

pub fn set_region(&mut self, region: Region)

Set the region

pub fn with_region(self, region: Region) -> Self

Set the region (builder style)

pub fn auth_type(&self) -> Option<&str>

Get the authentication type

pub fn set_auth_type(&mut self, auth_type: impl Into<String>)

Set the authentication type

pub fn with_auth_type(self, auth_type: impl Into<String>) -> Self

Set the authentication type (builder style)

pub fn delegation_token(&self) -> Option<&str>

Get the delegation token

pub fn set_delegation_token(&mut self, token: impl Into<String>)

Set the delegation token

pub fn with_delegation_token(self, token: impl Into<String>) -> Self

Set the delegation token (builder style)

pub fn session_token(&self) -> Option<&str>

Get the session token

pub fn set_session_token(&mut self, token: impl Into<String>)

Set the session token

pub fn with_session_token(self, token: impl Into<String>) -> Self

Set the session token (builder style)