BootVolume

Struct BootVolume 

pub struct BootVolume {
Show 22 fields pub availability_domain: String, pub compartment_id: String, pub id: String, pub lifecycle_state: BootVolumeLifecycleState, pub size_in_mbs: i64, pub time_created: DateTime<Utc>, pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>, pub system_tags: Option<HashMap<String, HashMap<String, Value>>>, pub display_name: Option<String>, pub freeform_tags: Option<HashMap<String, String>>, pub image_id: Option<String>, pub is_hydrated: Option<bool>, pub cluster_placement_group_id: Option<String>, pub vpus_per_gb: Option<i64>, pub size_in_gbs: Option<i64>, pub source_details: Option<BootVolumeSourceFromBootVolumeBackupDetails>, pub volume_group_id: Option<String>, pub kms_key_id: Option<String>, pub is_auto_tune_enabled: Option<bool>, pub auto_tuned_vpus_per_gb: Option<i64>, pub boot_volume_replicas: Option<Vec<BootVolumeReplicaInfo>>, pub autotune_policies: Option<Vec<AutotunePolicy>>,
}
A detachable boot volume device that contains the image used to boot a Compute instance. For more information, see Overview of Boot Volumes.

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.

Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Fields

availability_domain: String

The availability domain of the boot volume.

Example: {@code Uocm:PHX-AD-1}

compartment_id: String

The OCID of the compartment that contains the boot volume.

id: String

The boot volume’s Oracle ID (OCID).

lifecycle_state: BootVolumeLifecycleState

The current state of a boot volume.

size_in_mbs: i64

The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Please use sizeInGBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

time_created: DateTime<Utc>

The date and time the boot volume was created. Format defined by RFC3339.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

system_tags: Option<HashMap<String, HashMap<String, Value>>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: {@code {"foo-namespace": {"bar-key": "value"}}}

display_name: Option<String>

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

image_id: Option<String>

The image OCID used to create the boot volume.

is_hydrated: Option<bool>

Specifies whether the boot volume’s data has finished copying from the source boot volume or boot volume backup.

cluster_placement_group_id: Option<String>

The clusterPlacementGroup Id of the volume for volume placement.

vpus_per_gb: Option<i64>

The number of volume performance units (VPUs) that will be applied to this boot volume per GB, representing the Block Volume service’s elastic performance options. See Block Volume Performance Levels for more information.

Allowed values:

{@code 10}: Represents Balanced option.

{@code 20}: Represents Higher Performance option.

{@code 30}-{@code 120}: Represents the Ultra High Performance option.

For performance autotune enabled volumes, it would be the Default(Minimum) VPUs/GB. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

size_in_gbs: Option<i64>

The size of the boot volume in GBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

source_details: Option<BootVolumeSourceFromBootVolumeBackupDetails>volume_group_id: Option<String>

The OCID of the source volume group.

kms_key_id: Option<String>

The OCID of the Vault service master encryption key assigned to the boot volume.

is_auto_tune_enabled: Option<bool>

Specifies whether the auto-tune performance is enabled for this boot volume. This field is deprecated. Use the {@code DetachedVolumeAutotunePolicy} instead to enable the volume for detached autotune.

auto_tuned_vpus_per_gb: Option<i64>

The number of Volume Performance Units per GB that this boot volume is effectively tuned to. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

boot_volume_replicas: Option<Vec<BootVolumeReplicaInfo>>

The list of boot volume replicas of this boot volume

autotune_policies: Option<Vec<AutotunePolicy>>

The list of autotune policies enabled for this volume.

Implementations

Source

impl BootVolume

pub fn new(required: BootVolumeRequired) -> Self

Create a new BootVolume with required fields

pub fn set_availability_domain(self, value: String) -> Self

Set availability_domain

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_system_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set system_tags

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_image_id(self, value: Option<String>) -> Self

Set image_id

pub fn set_is_hydrated(self, value: Option<bool>) -> Self

Set is_hydrated

pub fn set_cluster_placement_group_id(self, value: Option<String>) -> Self

Set cluster_placement_group_id

pub fn set_vpus_per_gb(self, value: Option<i64>) -> Self

Set vpus_per_gb

pub fn set_lifecycle_state(self, value: BootVolumeLifecycleState) -> Self

Set lifecycle_state

pub fn set_size_in_gbs(self, value: Option<i64>) -> Self

Set size_in_gbs

pub fn set_size_in_mbs(self, value: i64) -> Self

Set size_in_mbs

pub fn set_source_details( self, value: Option<BootVolumeSourceFromBootVolumeBackupDetails>, ) -> Self

Set source_details

pub fn set_time_created(self, value: DateTime<Utc>) -> Self

Set time_created

pub fn set_volume_group_id(self, value: Option<String>) -> Self

Set volume_group_id

pub fn set_kms_key_id(self, value: Option<String>) -> Self

Set kms_key_id

pub fn set_is_auto_tune_enabled(self, value: Option<bool>) -> Self

Set is_auto_tune_enabled

pub fn set_auto_tuned_vpus_per_gb(self, value: Option<i64>) -> Self

Set auto_tuned_vpus_per_gb

pub fn set_boot_volume_replicas( self, value: Option<Vec<BootVolumeReplicaInfo>>, ) -> Self

Set boot_volume_replicas

pub fn set_autotune_policies(self, value: Option<Vec<AutotunePolicy>>) -> Self

Set autotune_policies

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_system_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set system_tags (unwraps Option)

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_image_id(self, value: impl Into<String>) -> Self

Set image_id (unwraps Option)

pub fn with_is_hydrated(self, value: bool) -> Self

Set is_hydrated (unwraps Option)

pub fn with_cluster_placement_group_id(self, value: impl Into<String>) -> Self

Set cluster_placement_group_id (unwraps Option)

pub fn with_vpus_per_gb(self, value: i64) -> Self

Set vpus_per_gb (unwraps Option)

pub fn with_size_in_gbs(self, value: i64) -> Self

Set size_in_gbs (unwraps Option)

pub fn with_source_details( self, value: BootVolumeSourceFromBootVolumeBackupDetails, ) -> Self

Set source_details (unwraps Option)

pub fn with_volume_group_id(self, value: impl Into<String>) -> Self

Set volume_group_id (unwraps Option)

pub fn with_kms_key_id(self, value: impl Into<String>) -> Self

Set kms_key_id (unwraps Option)

pub fn with_is_auto_tune_enabled(self, value: bool) -> Self

Set is_auto_tune_enabled (unwraps Option)

pub fn with_auto_tuned_vpus_per_gb(self, value: i64) -> Self

Set auto_tuned_vpus_per_gb (unwraps Option)

pub fn with_boot_volume_replicas( self, value: Vec<BootVolumeReplicaInfo>, ) -> Self

Set boot_volume_replicas (unwraps Option)

pub fn with_autotune_policies(self, value: Vec<AutotunePolicy>) -> Self

Set autotune_policies (unwraps Option)