pub struct BootVolumeRequired {
pub availability_domain: String,
pub compartment_id: String,
pub id: String,
pub lifecycle_state: BootVolumeLifecycleState,
pub size_in_mbs: i64,
pub time_created: DateTime<Utc>,
}Expand description
Required fields for BootVolume
Fields
availability_domain: StringThe availability domain of the boot volume.
Example: {@code Uocm:PHX-AD-1}
compartment_id: StringThe OCID of the compartment that contains the boot volume.
id: StringThe boot volume’s Oracle ID (OCID).
lifecycle_state: BootVolumeLifecycleStateThe current state of a boot volume.
size_in_mbs: i64The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Please use sizeInGBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
time_created: DateTime<Utc>The date and time the boot volume was created. Format defined by RFC3339.