pub struct BootVolumeBackup {Show 18 fields
pub compartment_id: String,
pub display_name: String,
pub id: String,
pub lifecycle_state: BootVolumeBackupLifecycleState,
pub time_created: DateTime<Utc>,
pub boot_volume_id: Option<String>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub system_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub expiration_time: Option<DateTime<Utc>>,
pub freeform_tags: Option<HashMap<String, String>>,
pub image_id: Option<String>,
pub kms_key_id: Option<String>,
pub size_in_gbs: Option<i64>,
pub source_boot_volume_backup_id: Option<String>,
pub source_type: Option<BootVolumeBackupSourceType>,
pub time_request_received: Option<DateTime<Utc>>,
pub type: Option<BootVolumeBackupType>,
pub unique_size_in_gbs: Option<i64>,
}Expand description
A point-in-time copy of a boot volume that can then be used to create a new boot volume or recover a boot volume. For more information, see Overview of Boot Volume Backups To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.
Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Fields
compartment_id: StringThe OCID of the compartment that contains the boot volume backup.
display_name: StringA user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
id: StringThe OCID of the boot volume backup.
lifecycle_state: BootVolumeBackupLifecycleStateThe current state of a boot volume backup.
time_created: DateTime<Utc>The date and time the boot volume backup was created. This is the time the actual point-in-time image of the volume data was taken. Format defined by RFC3339.
boot_volume_id: Option<String>The OCID of the boot volume.
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
System tags for this resource. Each key is predefined and scoped to a namespace. Example: {@code {"foo-namespace": {"bar-key": "value"}}}
expiration_time: Option<DateTime<Utc>>The date and time the volume backup will expire and be automatically deleted. Format defined by RFC3339. This parameter will always be present for backups that were created automatically by a scheduled-backup policy. For manually created backups, it will be absent, signifying that there is no expiration time and the backup will last forever until manually deleted.
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
image_id: Option<String>The image OCID used to create the boot volume the backup is taken from.
kms_key_id: Option<String>The OCID of the Vault service master encryption assigned to the boot volume backup. For more information about the Vault service and encryption keys, see Overview of Vault service and Using Keys.
size_in_gbs: Option<i64>The size of the boot volume, in GBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
source_boot_volume_backup_id: Option<String>The OCID of the source boot volume backup.
source_type: Option<BootVolumeBackupSourceType>Specifies whether the backup was created manually, or via scheduled backup policy.
time_request_received: Option<DateTime<Utc>>The date and time the request to create the boot volume backup was received. Format defined by RFC3339.
type: Option<BootVolumeBackupType>The type of a volume backup.
unique_size_in_gbs: Option<i64>The size used by the backup, in GBs. It is typically smaller than sizeInGBs, depending on the space consumed on the boot volume and whether the backup is full or incremental. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
Implementations
Sourceimpl BootVolumeBackup
impl BootVolumeBackup
Sourcepub fn new(required: BootVolumeBackupRequired) -> Self
pub fn new(required: BootVolumeBackupRequired) -> Self
Create a new BootVolumeBackup with required fields
Sourcepub fn set_boot_volume_id(self, value: Option<String>) -> Self
pub fn set_boot_volume_id(self, value: Option<String>) -> Self
Set boot_volume_id
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Set defined_tags
Set system_tags
Sourcepub fn set_display_name(self, value: String) -> Self
pub fn set_display_name(self, value: String) -> Self
Set display_name
Sourcepub fn set_expiration_time(self, value: Option<DateTime<Utc>>) -> Self
pub fn set_expiration_time(self, value: Option<DateTime<Utc>>) -> Self
Set expiration_time
Set freeform_tags
Sourcepub fn set_image_id(self, value: Option<String>) -> Self
pub fn set_image_id(self, value: Option<String>) -> Self
Set image_id
Sourcepub fn set_kms_key_id(self, value: Option<String>) -> Self
pub fn set_kms_key_id(self, value: Option<String>) -> Self
Set kms_key_id
Sourcepub fn set_lifecycle_state(self, value: BootVolumeBackupLifecycleState) -> Self
pub fn set_lifecycle_state(self, value: BootVolumeBackupLifecycleState) -> Self
Set lifecycle_state
Sourcepub fn set_size_in_gbs(self, value: Option<i64>) -> Self
pub fn set_size_in_gbs(self, value: Option<i64>) -> Self
Set size_in_gbs
Sourcepub fn set_source_boot_volume_backup_id(self, value: Option<String>) -> Self
pub fn set_source_boot_volume_backup_id(self, value: Option<String>) -> Self
Set source_boot_volume_backup_id
Sourcepub fn set_source_type(self, value: Option<BootVolumeBackupSourceType>) -> Self
pub fn set_source_type(self, value: Option<BootVolumeBackupSourceType>) -> Self
Set source_type
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Sourcepub fn set_time_request_received(self, value: Option<DateTime<Utc>>) -> Self
pub fn set_time_request_received(self, value: Option<DateTime<Utc>>) -> Self
Set time_request_received
Sourcepub fn set_type(self, value: Option<BootVolumeBackupType>) -> Self
pub fn set_type(self, value: Option<BootVolumeBackupType>) -> Self
Set r#type
Sourcepub fn set_unique_size_in_gbs(self, value: Option<i64>) -> Self
pub fn set_unique_size_in_gbs(self, value: Option<i64>) -> Self
Set unique_size_in_gbs
Sourcepub fn with_boot_volume_id(self, value: impl Into<String>) -> Self
pub fn with_boot_volume_id(self, value: impl Into<String>) -> Self
Set boot_volume_id (unwraps Option)
Set defined_tags (unwraps Option)
Set system_tags (unwraps Option)
Sourcepub fn with_expiration_time(self, value: DateTime<Utc>) -> Self
pub fn with_expiration_time(self, value: DateTime<Utc>) -> Self
Set expiration_time (unwraps Option)
Set freeform_tags (unwraps Option)
Sourcepub fn with_image_id(self, value: impl Into<String>) -> Self
pub fn with_image_id(self, value: impl Into<String>) -> Self
Set image_id (unwraps Option)
Sourcepub fn with_kms_key_id(self, value: impl Into<String>) -> Self
pub fn with_kms_key_id(self, value: impl Into<String>) -> Self
Set kms_key_id (unwraps Option)
Sourcepub fn with_size_in_gbs(self, value: i64) -> Self
pub fn with_size_in_gbs(self, value: i64) -> Self
Set size_in_gbs (unwraps Option)
Sourcepub fn with_source_boot_volume_backup_id(self, value: impl Into<String>) -> Self
pub fn with_source_boot_volume_backup_id(self, value: impl Into<String>) -> Self
Set source_boot_volume_backup_id (unwraps Option)
Sourcepub fn with_source_type(self, value: BootVolumeBackupSourceType) -> Self
pub fn with_source_type(self, value: BootVolumeBackupSourceType) -> Self
Set source_type (unwraps Option)
Sourcepub fn with_time_request_received(self, value: DateTime<Utc>) -> Self
pub fn with_time_request_received(self, value: DateTime<Utc>) -> Self
Set time_request_received (unwraps Option)
Sourcepub fn with_type(self, value: BootVolumeBackupType) -> Self
pub fn with_type(self, value: BootVolumeBackupType) -> Self
Set r#type (unwraps Option)
Sourcepub fn with_unique_size_in_gbs(self, value: i64) -> Self
pub fn with_unique_size_in_gbs(self, value: i64) -> Self
Set unique_size_in_gbs (unwraps Option)