pub struct BootVolumeBackupRequired {
pub compartment_id: String,
pub display_name: String,
pub id: String,
pub lifecycle_state: BootVolumeBackupLifecycleState,
pub time_created: DateTime<Utc>,
}Expand description
Required fields for BootVolumeBackup
Fields
compartment_id: StringThe OCID of the compartment that contains the boot volume backup.
display_name: StringA user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
id: StringThe OCID of the boot volume backup.
lifecycle_state: BootVolumeBackupLifecycleStateThe current state of a boot volume backup.
time_created: DateTime<Utc>The date and time the boot volume backup was created. This is the time the actual point-in-time image of the volume data was taken. Format defined by RFC3339.