pub struct ComputeClusterCollection {
pub items: Vec<ComputeClusterSummary>,
}Expand description
A list of compute clusters that match filter criteria, if any. A compute cluster is a remote direct memory access (RDMA) network group.
Fields
items: Vec<ComputeClusterSummary>The list of compute clusters.
Implementations
Sourceimpl ComputeClusterCollection
impl ComputeClusterCollection
Sourcepub fn new(required: ComputeClusterCollectionRequired) -> Self
pub fn new(required: ComputeClusterCollectionRequired) -> Self
Create a new ComputeClusterCollection with required fields
Sourcepub fn set_items(self, value: Vec<ComputeClusterSummary>) -> Self
pub fn set_items(self, value: Vec<ComputeClusterSummary>) -> Self
Set items