pub enum ConfigurationState {
Conformant,
NonConformant,
Checking,
PreApplying,
Applying,
Unknown,
UnknownValue,
}Expand description
The current state of the host configuration. The Host is either CONFORMANT - current state matches the desired configuration NON_CONFORMANT - current state does not match the desired configuration PRE_APPLYING, APPLYING, CHECKING - transitional states UNKNOWN - current state is unknown
Variants
Conformant
NonConformant
Checking
PreApplying
Applying
Unknown
UnknownValue
This value is used if a service returns a value for this enum that is not recognized by this version of the SDK.