Image

Struct Image 

pub struct Image {
Show 17 fields pub compartment_id: String, pub create_image_allowed: bool, pub id: String, pub lifecycle_state: ImageLifecycleState, pub operating_system: String, pub operating_system_version: String, pub time_created: DateTime<Utc>, pub base_image_id: Option<String>, pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>, pub display_name: Option<String>, pub freeform_tags: Option<HashMap<String, String>>, pub launch_mode: Option<ImageLaunchMode>, pub launch_options: Option<LaunchOptions>, pub agent_features: Option<InstanceAgentFeatures>, pub listing_type: Option<ImageListingType>, pub size_in_mbs: Option<i64>, pub billable_size_in_gbs: Option<i64>,
}
A boot disk image for launching an instance. For more information, see Overview of the Compute Service.

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.

Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Fields

compartment_id: String

The OCID of the compartment containing the instance you want to use as the basis for the image.

create_image_allowed: bool

Whether instances launched with this image can be used to create new images. For example, you cannot create an image of an Oracle Database instance.

Example: {@code true}

id: String

The OCID of the image.

lifecycle_state: ImageLifecycleStateoperating_system: String

The image’s operating system.

Example: {@code Oracle Linux}

operating_system_version: String

The image’s operating system version.

Example: {@code 7.2}

time_created: DateTime<Utc>

The date and time the image was created, in the format defined by RFC3339.

Example: {@code 2016-08-25T21:10:29.600Z}

base_image_id: Option<String>

The OCID of the image originally used to launch the instance.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

display_name: Option<String>

A user-friendly name for the image. It does not have to be unique, and it’s changeable. Avoid entering confidential information.

You cannot use a platform image name as a custom image name.

Example: {@code My custom Oracle Linux image}

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

launch_mode: Option<ImageLaunchMode>

Specifies the configuration mode for launching virtual machine (VM) instances. The configuration modes are: * {@code NATIVE} - VM instances launch with iSCSI boot and VFIO devices. The default value for platform images. * {@code EMULATED} - VM instances launch with emulated devices, such as the E1000 network driver and emulated SCSI disk controller. * {@code PARAVIRTUALIZED} - VM instances launch with paravirtualized devices using VirtIO drivers. * {@code CUSTOM} - VM instances launch with custom configuration settings specified in the {@code LaunchOptions} parameter.

launch_options: Option<LaunchOptions>agent_features: Option<InstanceAgentFeatures>listing_type: Option<ImageListingType>

The listing type of the image. The default value is "NONE".

size_in_mbs: Option<i64>

The boot volume size for an instance launched from this image (1 MB = 1,048,576 bytes). Note this is not the same as the size of the image when it was exported or the actual size of the image.

Example: {@code 47694} Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

billable_size_in_gbs: Option<i64>

The size of the internal storage for this image that is subject to billing (1 GB = 1,073,741,824 bytes).

Example: {@code 100} Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

Implementations

Source

impl Image

pub fn new(required: ImageRequired) -> Self

Create a new Image with required fields

pub fn set_base_image_id(self, value: Option<String>) -> Self

Set base_image_id

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_create_image_allowed(self, value: bool) -> Self

Set create_image_allowed

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_launch_mode(self, value: Option<ImageLaunchMode>) -> Self

Set launch_mode

pub fn set_launch_options(self, value: Option<LaunchOptions>) -> Self

Set launch_options

pub fn set_lifecycle_state(self, value: ImageLifecycleState) -> Self

Set lifecycle_state

pub fn set_operating_system(self, value: String) -> Self

Set operating_system

pub fn set_operating_system_version(self, value: String) -> Self

Set operating_system_version

pub fn set_agent_features(self, value: Option<InstanceAgentFeatures>) -> Self

Set agent_features

pub fn set_listing_type(self, value: Option<ImageListingType>) -> Self

Set listing_type

pub fn set_size_in_mbs(self, value: Option<i64>) -> Self

Set size_in_mbs

pub fn set_billable_size_in_gbs(self, value: Option<i64>) -> Self

Set billable_size_in_gbs

pub fn set_time_created(self, value: DateTime<Utc>) -> Self

Set time_created

pub fn with_base_image_id(self, value: impl Into<String>) -> Self

Set base_image_id (unwraps Option)

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_launch_mode(self, value: ImageLaunchMode) -> Self

Set launch_mode (unwraps Option)

pub fn with_launch_options(self, value: LaunchOptions) -> Self

Set launch_options (unwraps Option)

pub fn with_agent_features(self, value: InstanceAgentFeatures) -> Self

Set agent_features (unwraps Option)

pub fn with_listing_type(self, value: ImageListingType) -> Self

Set listing_type (unwraps Option)

pub fn with_size_in_mbs(self, value: i64) -> Self

Set size_in_mbs (unwraps Option)

pub fn with_billable_size_in_gbs(self, value: i64) -> Self

Set billable_size_in_gbs (unwraps Option)