pub struct ImageRequired {
pub compartment_id: String,
pub create_image_allowed: bool,
pub id: String,
pub lifecycle_state: ImageLifecycleState,
pub operating_system: String,
pub operating_system_version: String,
pub time_created: DateTime<Utc>,
}Expand description
Required fields for Image
Fields
compartment_id: StringThe OCID of the compartment containing the instance you want to use as the basis for the image.
create_image_allowed: boolWhether instances launched with this image can be used to create new images. For example, you cannot create an image of an Oracle Database instance.
Example: {@code true}
id: StringThe OCID of the image.
lifecycle_state: ImageLifecycleStateoperating_system: StringThe image’s operating system.
Example: {@code Oracle Linux}
operating_system_version: StringThe image’s operating system version.
Example: {@code 7.2}
time_created: DateTime<Utc>The date and time the image was created, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}