pub struct InstanceRequired {
pub availability_domain: String,
pub compartment_id: String,
pub id: String,
pub lifecycle_state: InstanceLifecycleState,
pub region: String,
pub shape: String,
pub time_created: DateTime<Utc>,
}Expand description
Required fields for Instance
Fields
availability_domain: StringThe availability domain the instance is running in.
Example: {@code Uocm:PHX-AD-1}
compartment_id: StringThe OCID of the compartment that contains the instance.
id: StringThe OCID of the instance.
lifecycle_state: InstanceLifecycleStateThe current state of the instance.
region: StringThe region that contains the availability domain the instance is running in.
For the us-phoenix-1 and us-ashburn-1 regions, {@code phx} and {@code iad} are returned, respectively. For all other regions, the full region name is returned.
Examples: {@code phx}, {@code eu-frankfurt-1}
shape: StringThe shape of the instance. The shape determines the number of CPUs and the amount of memory allocated to the instance. You can enumerate all available shapes by calling {@link #listShapes(ListShapesRequest) listShapes}.
time_created: DateTime<Utc>The date and time the instance was created, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}