pub struct InstanceAvailabilityConfig {
pub is_live_migration_preferred: Option<bool>,
pub recovery_action: Option<InstanceAvailabilityConfigRecoveryAction>,
}Expand description
Options for defining the availabiity of a VM instance after a maintenance event that impacts the underlying hardware.
Fields
is_live_migration_preferred: Option<bool>Whether to live migrate supported VM instances to a healthy physical VM host without disrupting running instances during infrastructure maintenance events. If null, Oracle chooses the best option for migrating the VM during infrastructure maintenance events.
recovery_action: Option<InstanceAvailabilityConfigRecoveryAction>The lifecycle state for an instance when it is recovered after infrastructure maintenance. * {@code RESTORE_INSTANCE} - The instance is restored to the lifecycle state it was in before the maintenance event. If the instance was running, it is automatically rebooted. This is the default action when a value is not set. * {@code STOP_INSTANCE} - The instance is recovered in the stopped state.
Implementations
Sourceimpl InstanceAvailabilityConfig
impl InstanceAvailabilityConfig
Sourcepub fn set_is_live_migration_preferred(self, value: Option<bool>) -> Self
pub fn set_is_live_migration_preferred(self, value: Option<bool>) -> Self
Set is_live_migration_preferred
Sourcepub fn set_recovery_action(
self,
value: Option<InstanceAvailabilityConfigRecoveryAction>,
) -> Self
pub fn set_recovery_action( self, value: Option<InstanceAvailabilityConfigRecoveryAction>, ) -> Self
Set recovery_action
Sourcepub fn with_is_live_migration_preferred(self, value: bool) -> Self
pub fn with_is_live_migration_preferred(self, value: bool) -> Self
Set is_live_migration_preferred (unwraps Option)
Sourcepub fn with_recovery_action(
self,
value: InstanceAvailabilityConfigRecoveryAction,
) -> Self
pub fn with_recovery_action( self, value: InstanceAvailabilityConfigRecoveryAction, ) -> Self
Set recovery_action (unwraps Option)