InstanceConfiguration

Struct InstanceConfiguration 

pub struct InstanceConfiguration {
    pub compartment_id: String,
    pub id: String,
    pub time_created: DateTime<Utc>,
    pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
    pub display_name: Option<String>,
    pub freeform_tags: Option<HashMap<String, String>>,
    pub instance_details: Option<ComputeInstanceOptions>,
    pub deferred_fields: Option<Vec<String>>,
}
An instance configuration is a template that defines the settings to use when creating Compute instances. For more information about instance configurations, see Managing Compute Instances.

Fields

compartment_id: String

The OCID of the compartment containing the instance configuration.

id: String

The OCID of the instance configuration.

time_created: DateTime<Utc>

The date and time the instance configuration was created, in the format defined by RFC3339.

Example: {@code 2016-08-25T21:10:29.600Z}

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

display_name: Option<String>

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

instance_details: Option<ComputeInstanceOptions>deferred_fields: Option<Vec<String>>

Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the {@link #launchInstanceConfiguration(LaunchInstanceConfigurationRequest) launchInstanceConfiguration} operation.

Implementations

Source

impl InstanceConfiguration

pub fn new(required: InstanceConfigurationRequired) -> Self

Create a new InstanceConfiguration with required fields

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_instance_details(self, value: Option<ComputeInstanceOptions>) -> Self

Set instance_details

pub fn set_deferred_fields(self, value: Option<Vec<String>>) -> Self

Set deferred_fields

pub fn set_time_created(self, value: DateTime<Utc>) -> Self

Set time_created

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_instance_details(self, value: ComputeInstanceOptions) -> Self

Set instance_details (unwraps Option)

pub fn with_deferred_fields(self, value: Vec<String>) -> Self

Set deferred_fields (unwraps Option)