pub struct InstanceConfigurationSummary {
pub compartment_id: String,
pub id: String,
pub time_created: DateTime<Utc>,
pub display_name: Option<String>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub freeform_tags: Option<HashMap<String, String>>,
}Expand description
Summary information for an instance configuration.
Fields
compartment_id: StringThe OCID of the compartment containing the instance configuration.
id: StringThe OCID of the instance configuration.
time_created: DateTime<Utc>The date and time the instance configuration was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
Implementations
Sourceimpl InstanceConfigurationSummary
impl InstanceConfigurationSummary
Sourcepub fn new(required: InstanceConfigurationSummaryRequired) -> Self
pub fn new(required: InstanceConfigurationSummaryRequired) -> Self
Create a new InstanceConfigurationSummary with required fields
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Set defined_tags
Set freeform_tags
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Set defined_tags (unwraps Option)
Set freeform_tags (unwraps Option)