InstanceConsoleConnection

Struct InstanceConsoleConnection 

pub struct InstanceConsoleConnection {
    pub compartment_id: Option<String>,
    pub connection_string: Option<String>,
    pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
    pub fingerprint: Option<String>,
    pub freeform_tags: Option<HashMap<String, String>>,
    pub id: Option<String>,
    pub instance_id: Option<String>,
    pub lifecycle_state: Option<InstanceConsoleConnectionLifecycleState>,
    pub service_host_key_fingerprint: Option<String>,
    pub vnc_connection_string: Option<String>,
}
The {@code InstanceConsoleConnection} API provides you with console access to Compute instances, enabling you to troubleshoot malfunctioning instances remotely.

For more information about instance console connections, see Troubleshooting Instances Using Instance Console Connections.

Fields

compartment_id: Option<String>

The OCID of the compartment to contain the console connection.

connection_string: Option<String>

The SSH connection string for the console connection.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

fingerprint: Option<String>

The SSH public key’s fingerprint for client authentication to the console connection.

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

id: Option<String>

The OCID of the console connection.

instance_id: Option<String>

The OCID of the instance the console connection connects to.

lifecycle_state: Option<InstanceConsoleConnectionLifecycleState>

The current state of the console connection.

service_host_key_fingerprint: Option<String>

The SSH public key’s fingerprint for the console connection service host.

vnc_connection_string: Option<String>

The SSH connection string for the SSH tunnel used to connect to the console connection over VNC.

Implementations

Source

impl InstanceConsoleConnection

pub fn new() -> Self

Create a new InstanceConsoleConnection

pub fn set_compartment_id(self, value: Option<String>) -> Self

Set compartment_id

pub fn set_connection_string(self, value: Option<String>) -> Self

Set connection_string

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_fingerprint(self, value: Option<String>) -> Self

Set fingerprint

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: Option<String>) -> Self

Set id

pub fn set_instance_id(self, value: Option<String>) -> Self

Set instance_id

pub fn set_lifecycle_state( self, value: Option<InstanceConsoleConnectionLifecycleState>, ) -> Self

Set lifecycle_state

pub fn set_service_host_key_fingerprint(self, value: Option<String>) -> Self

Set service_host_key_fingerprint

pub fn set_vnc_connection_string(self, value: Option<String>) -> Self

Set vnc_connection_string

pub fn with_compartment_id(self, value: impl Into<String>) -> Self

Set compartment_id (unwraps Option)

pub fn with_connection_string(self, value: impl Into<String>) -> Self

Set connection_string (unwraps Option)

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_fingerprint(self, value: impl Into<String>) -> Self

Set fingerprint (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_id(self, value: impl Into<String>) -> Self

Set id (unwraps Option)

pub fn with_instance_id(self, value: impl Into<String>) -> Self

Set instance_id (unwraps Option)

pub fn with_lifecycle_state( self, value: InstanceConsoleConnectionLifecycleState, ) -> Self

Set lifecycle_state (unwraps Option)

pub fn with_service_host_key_fingerprint(self, value: impl Into<String>) -> Self

Set service_host_key_fingerprint (unwraps Option)

pub fn with_vnc_connection_string(self, value: impl Into<String>) -> Self

Set vnc_connection_string (unwraps Option)