InstanceMaintenanceEvent

Struct InstanceMaintenanceEvent 

pub struct InstanceMaintenanceEvent {
Show 25 fields pub id: String, pub instance_id: String, pub compartment_id: String, pub maintenance_category: InstanceMaintenanceEventMaintenanceCategory, pub maintenance_reason: InstanceMaintenanceEventMaintenanceReason, pub instance_action: InstanceMaintenanceEventInstanceAction, pub alternative_resolution_actions: Vec<InstanceMaintenanceEventAlternativeResolutionActions>, pub time_window_start: DateTime<Utc>, pub can_reschedule: bool, pub time_created: DateTime<Utc>, pub lifecycle_state: InstanceMaintenanceEventLifecycleState, pub created_by: InstanceMaintenanceEventCreatedBy, pub display_name: Option<String>, pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>, pub freeform_tags: Option<HashMap<String, String>>, pub time_started: Option<DateTime<Utc>>, pub time_finished: Option<DateTime<Utc>>, pub start_window_duration: Option<String>, pub estimated_duration: Option<String>, pub time_hard_due_date: Option<DateTime<Utc>>, pub lifecycle_details: Option<String>, pub description: Option<String>, pub correlation_token: Option<String>, pub can_delete_local_storage: Option<bool>, pub additional_details: Option<HashMap<String, String>>,
}
It is the event in which the maintenance action will be be performed on the customer instance on the scheduled date and time.

Fields

id: String

The OCID of the maintenance event.

instance_id: String

The OCID of the instance.

compartment_id: String

The OCID of the compartment that contains the instance.

maintenance_category: InstanceMaintenanceEventMaintenanceCategory

This indicates the priority and allowed actions for this Maintenance. Higher priority forms of Maintenance have tighter restrictions and may not be rescheduled, while lower priority/severity Maintenance can be rescheduled, deferred, or even cancelled. Please see the Instance Maintenance documentation for details.

maintenance_reason: InstanceMaintenanceEventMaintenanceReason

This is the reason that Maintenance is being performed. See Instance Maintenance documentation for details.

instance_action: InstanceMaintenanceEventInstanceAction

This is the action that will be performed on the Instance by OCI when the Maintenance begins.

alternative_resolution_actions: Vec<InstanceMaintenanceEventAlternativeResolutionActions>

These are alternative actions to the requested instanceAction that can be taken to resolve the Maintenance.

time_window_start: DateTime<Utc>

The beginning of the time window when Maintenance is scheduled to begin. The Maintenance will not begin before this time.

can_reschedule: bool

Indicates if this MaintenanceEvent is capable of being rescheduled up to the timeHardDueDate.

time_created: DateTime<Utc>

The date and time the maintenance event was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}

lifecycle_state: InstanceMaintenanceEventLifecycleState

The current state of the maintenance event.

created_by: InstanceMaintenanceEventCreatedBy

The creator of the maintenance event.

display_name: Option<String>

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

time_started: Option<DateTime<Utc>>

The time at which the Maintenance actually started.

time_finished: Option<DateTime<Utc>>

The time at which the Maintenance actually finished.

start_window_duration: Option<String>

The duration of the time window Maintenance is scheduled to begin within.

estimated_duration: Option<String>

This is the estimated duration of the Maintenance, once the Maintenance has entered the STARTED state.

time_hard_due_date: Option<DateTime<Utc>>

It is the scheduled hard due date and time of the maintenance event. The maintenance event will happen at this time and the due date will not be extended.

lifecycle_details: Option<String>

Provides more details about the state of the maintenance event.

description: Option<String>

It is the descriptive information about the maintenance taking place on the customer instance.

correlation_token: Option<String>

A unique identifier that will group Instances that have a relationship with one another and must be scheduled together for the Maintenance to proceed. Any Instances that have a relationship with one another from a Maintenance perspective will have a matching correlationToken.

can_delete_local_storage: Option<bool>

For Instances that have local storage, this field is set to true when local storage will be deleted as a result of the Maintenance.

additional_details: Option<HashMap<String, String>>

Additional details of the maintenance in the form of json.

Implementations

Source

impl InstanceMaintenanceEvent

pub fn new(required: InstanceMaintenanceEventRequired) -> Self

Create a new InstanceMaintenanceEvent with required fields

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_instance_id(self, value: String) -> Self

Set instance_id

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_maintenance_category( self, value: InstanceMaintenanceEventMaintenanceCategory, ) -> Self

Set maintenance_category

pub fn set_maintenance_reason( self, value: InstanceMaintenanceEventMaintenanceReason, ) -> Self

Set maintenance_reason

pub fn set_instance_action( self, value: InstanceMaintenanceEventInstanceAction, ) -> Self

Set instance_action

pub fn set_alternative_resolution_actions( self, value: Vec<InstanceMaintenanceEventAlternativeResolutionActions>, ) -> Self

Set alternative_resolution_actions

pub fn set_time_started(self, value: Option<DateTime<Utc>>) -> Self

Set time_started

pub fn set_time_finished(self, value: Option<DateTime<Utc>>) -> Self

Set time_finished

pub fn set_time_window_start(self, value: DateTime<Utc>) -> Self

Set time_window_start

pub fn set_start_window_duration(self, value: Option<String>) -> Self

Set start_window_duration

pub fn set_estimated_duration(self, value: Option<String>) -> Self

Set estimated_duration

pub fn set_time_hard_due_date(self, value: Option<DateTime<Utc>>) -> Self

Set time_hard_due_date

pub fn set_can_reschedule(self, value: bool) -> Self

Set can_reschedule

pub fn set_time_created(self, value: DateTime<Utc>) -> Self

Set time_created

pub fn set_lifecycle_state( self, value: InstanceMaintenanceEventLifecycleState, ) -> Self

Set lifecycle_state

pub fn set_lifecycle_details(self, value: Option<String>) -> Self

Set lifecycle_details

pub fn set_created_by(self, value: InstanceMaintenanceEventCreatedBy) -> Self

Set created_by

pub fn set_description(self, value: Option<String>) -> Self

Set description

pub fn set_correlation_token(self, value: Option<String>) -> Self

Set correlation_token

pub fn set_can_delete_local_storage(self, value: Option<bool>) -> Self

Set can_delete_local_storage

pub fn set_additional_details( self, value: Option<HashMap<String, String>>, ) -> Self

Set additional_details

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_time_started(self, value: DateTime<Utc>) -> Self

Set time_started (unwraps Option)

pub fn with_time_finished(self, value: DateTime<Utc>) -> Self

Set time_finished (unwraps Option)

pub fn with_start_window_duration(self, value: impl Into<String>) -> Self

Set start_window_duration (unwraps Option)

pub fn with_estimated_duration(self, value: impl Into<String>) -> Self

Set estimated_duration (unwraps Option)

pub fn with_time_hard_due_date(self, value: DateTime<Utc>) -> Self

Set time_hard_due_date (unwraps Option)

pub fn with_lifecycle_details(self, value: impl Into<String>) -> Self

Set lifecycle_details (unwraps Option)

pub fn with_description(self, value: impl Into<String>) -> Self

Set description (unwraps Option)

pub fn with_correlation_token(self, value: impl Into<String>) -> Self

Set correlation_token (unwraps Option)

pub fn with_can_delete_local_storage(self, value: bool) -> Self

Set can_delete_local_storage (unwraps Option)

pub fn with_additional_details(self, value: HashMap<String, String>) -> Self

Set additional_details (unwraps Option)