Module instance_pool

Module instance_pool 

Structs

InstancePool
An instance pool is a set of instances within the same region that are managed as a group. For more information about instance pools and instance configurations, see Managing Compute Instances.
InstancePoolRequired
Required fields for InstancePool