InstancePoolInstance

Struct InstancePoolInstance 

pub struct InstancePoolInstance {
Show 13 fields pub id: String, pub instance_pool_id: String, pub availability_domain: String, pub lifecycle_state: InstancePoolInstanceLifecycleState, pub compartment_id: String, pub instance_configuration_id: String, pub region: String, pub shape: String, pub state: String, pub time_created: DateTime<Utc>, pub display_name: Option<String>, pub fault_domain: Option<String>, pub load_balancer_backends: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>,
}
Information about an instance that belongs to an instance pool.

Fields

id: String

The OCID of the instance.

instance_pool_id: String

The OCID of the instance pool.

availability_domain: String

The availability domain the instance is running in.

lifecycle_state: InstancePoolInstanceLifecycleState

The attachment state of the instance in relation to the instance pool.

compartment_id: String

The OCID of the compartment that contains the instance.

instance_configuration_id: String

The OCID of the instance configuration used to create the instance.

region: String

The region that contains the availability domain the instance is running in.

shape: String

The shape of the instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.

state: String

The lifecycle state of the instance. Refer to {@code lifecycleState} in the {@link Instance} resource.

time_created: DateTime<Utc>

The date and time the instance pool instance was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}

display_name: Option<String>

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

fault_domain: Option<String>

The fault domain the instance is running in.

load_balancer_backends: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>

The load balancer backends that are configured for the instance.

Implementations

Source

impl InstancePoolInstance

pub fn new(required: InstancePoolInstanceRequired) -> Self

Create a new InstancePoolInstance with required fields

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_instance_pool_id(self, value: String) -> Self

Set instance_pool_id

pub fn set_availability_domain(self, value: String) -> Self

Set availability_domain

pub fn set_lifecycle_state( self, value: InstancePoolInstanceLifecycleState, ) -> Self

Set lifecycle_state

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_fault_domain(self, value: Option<String>) -> Self

Set fault_domain

pub fn set_instance_configuration_id(self, value: String) -> Self

Set instance_configuration_id

pub fn set_region(self, value: String) -> Self

Set region

pub fn set_shape(self, value: String) -> Self

Set shape

pub fn set_state(self, value: String) -> Self

Set state

pub fn set_time_created(self, value: DateTime<Utc>) -> Self

Set time_created

pub fn set_load_balancer_backends( self, value: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>, ) -> Self

Set load_balancer_backends

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_fault_domain(self, value: impl Into<String>) -> Self

Set fault_domain (unwraps Option)

pub fn with_load_balancer_backends( self, value: Vec<InstancePoolInstanceLoadBalancerBackend>, ) -> Self

Set load_balancer_backends (unwraps Option)