pub struct InstancePoolInstanceRequired {
pub id: String,
pub instance_pool_id: String,
pub availability_domain: String,
pub lifecycle_state: InstancePoolInstanceLifecycleState,
pub compartment_id: String,
pub instance_configuration_id: String,
pub region: String,
pub shape: String,
pub state: String,
pub time_created: DateTime<Utc>,
}Expand description
Required fields for InstancePoolInstance
Fields
id: StringThe OCID of the instance.
instance_pool_id: StringThe OCID of the instance pool.
availability_domain: StringThe availability domain the instance is running in.
lifecycle_state: InstancePoolInstanceLifecycleStateThe attachment state of the instance in relation to the instance pool.
compartment_id: StringThe OCID of the compartment that contains the instance.
instance_configuration_id: StringThe OCID of the instance configuration used to create the instance.
region: StringThe region that contains the availability domain the instance is running in.
shape: StringThe shape of the instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.
state: StringThe lifecycle state of the instance. Refer to {@code lifecycleState} in the {@link Instance} resource.
time_created: DateTime<Utc>The date and time the instance pool instance was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}