pub struct InstancePoolSummary {
pub id: String,
pub compartment_id: String,
pub instance_configuration_id: String,
pub lifecycle_state: InstancePoolSummaryLifecycleState,
pub availability_domains: Vec<String>,
pub size: i64,
pub time_created: DateTime<Utc>,
pub display_name: Option<String>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub freeform_tags: Option<HashMap<String, String>>,
}Expand description
Summary information for an instance pool.
Fields
id: StringThe OCID of the instance pool.
compartment_id: StringThe OCID of the compartment containing the instance pool.
instance_configuration_id: StringThe OCID of the instance configuration associated with the instance pool.
lifecycle_state: InstancePoolSummaryLifecycleStateThe current state of the instance pool.
availability_domains: Vec<String>The availability domains for the instance pool.
size: i64The number of instances that should be in the instance pool. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
time_created: DateTime<Utc>The date and time the instance pool was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
Implementations
Sourceimpl InstancePoolSummary
impl InstancePoolSummary
Sourcepub fn new(required: InstancePoolSummaryRequired) -> Self
pub fn new(required: InstancePoolSummaryRequired) -> Self
Create a new InstancePoolSummary with required fields
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Sourcepub fn set_instance_configuration_id(self, value: String) -> Self
pub fn set_instance_configuration_id(self, value: String) -> Self
Set instance_configuration_id
Sourcepub fn set_lifecycle_state(
self,
value: InstancePoolSummaryLifecycleState,
) -> Self
pub fn set_lifecycle_state( self, value: InstancePoolSummaryLifecycleState, ) -> Self
Set lifecycle_state
Sourcepub fn set_availability_domains(self, value: Vec<String>) -> Self
pub fn set_availability_domains(self, value: Vec<String>) -> Self
Set availability_domains
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Set defined_tags
Set freeform_tags
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Set defined_tags (unwraps Option)
Set freeform_tags (unwraps Option)