InstancePoolSummaryRequired

Struct InstancePoolSummaryRequired 

pub struct InstancePoolSummaryRequired {
    pub id: String,
    pub compartment_id: String,
    pub instance_configuration_id: String,
    pub lifecycle_state: InstancePoolSummaryLifecycleState,
    pub availability_domains: Vec<String>,
    pub size: i64,
    pub time_created: DateTime<Utc>,
}
Required fields for InstancePoolSummary

Fields

id: String

The OCID of the instance pool.

compartment_id: String

The OCID of the compartment containing the instance pool.

instance_configuration_id: String

The OCID of the instance configuration associated with the instance pool.

lifecycle_state: InstancePoolSummaryLifecycleState

The current state of the instance pool.

availability_domains: Vec<String>

The availability domains for the instance pool.

size: i64

The number of instances that should be in the instance pool. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

time_created: DateTime<Utc>

The date and time the instance pool was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}