InstanceReservationConfig

Struct InstanceReservationConfig 

pub struct InstanceReservationConfig {
    pub instance_shape: String,
    pub reserved_count: i64,
    pub used_count: i64,
    pub fault_domain: Option<String>,
    pub cluster_config: Option<ClusterConfigDetails>,
    pub instance_shape_config: Option<InstanceReservationShapeConfigDetails>,
    pub cluster_placement_group_id: Option<String>,
}
Data that defines the capacity configuration.

Fields

instance_shape: String

The shape to use when launching instances using compute capacity reservations. The shape determines the number of CPUs, the amount of memory, and other resources allocated to the instance. You can list all available shapes by calling {@link ListComputeCapacityReservationInstanceShapes}.

reserved_count: i64

The total number of instances that can be launched from the capacity configuration. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

used_count: i64

The amount of capacity in use out of the total capacity reserved in this capacity configuration. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

fault_domain: Option<String>

The fault domain of this capacity configuration. If a value is not supplied, this capacity configuration is applicable to all fault domains in the specified availability domain. For more information, see Capacity Reservations.

cluster_config: Option<ClusterConfigDetails>instance_shape_config: Option<InstanceReservationShapeConfigDetails>cluster_placement_group_id: Option<String>

The OCID of the cluster placement group for this instance reservation capacity configuration.

Implementations

Source

impl InstanceReservationConfig

pub fn new(required: InstanceReservationConfigRequired) -> Self

Create a new InstanceReservationConfig with required fields

pub fn set_fault_domain(self, value: Option<String>) -> Self

Set fault_domain

pub fn set_cluster_config(self, value: Option<ClusterConfigDetails>) -> Self

Set cluster_config

pub fn set_instance_shape(self, value: String) -> Self

Set instance_shape

pub fn set_instance_shape_config( self, value: Option<InstanceReservationShapeConfigDetails>, ) -> Self

Set instance_shape_config

pub fn set_reserved_count(self, value: i64) -> Self

Set reserved_count

pub fn set_used_count(self, value: i64) -> Self

Set used_count

pub fn set_cluster_placement_group_id(self, value: Option<String>) -> Self

Set cluster_placement_group_id

pub fn with_fault_domain(self, value: impl Into<String>) -> Self

Set fault_domain (unwraps Option)

pub fn with_cluster_config(self, value: ClusterConfigDetails) -> Self

Set cluster_config (unwraps Option)

pub fn with_instance_shape_config( self, value: InstanceReservationShapeConfigDetails, ) -> Self

Set instance_shape_config (unwraps Option)

pub fn with_cluster_placement_group_id(self, value: impl Into<String>) -> Self

Set cluster_placement_group_id (unwraps Option)