InstanceReservationConfigRequired

Struct InstanceReservationConfigRequired 

pub struct InstanceReservationConfigRequired {
    pub instance_shape: String,
    pub reserved_count: i64,
    pub used_count: i64,
}
Required fields for InstanceReservationConfig

Fields

instance_shape: String

The shape to use when launching instances using compute capacity reservations. The shape determines the number of CPUs, the amount of memory, and other resources allocated to the instance. You can list all available shapes by calling {@link ListComputeCapacityReservationInstanceShapes}.

reserved_count: i64

The total number of instances that can be launched from the capacity configuration. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

used_count: i64

The amount of capacity in use out of the total capacity reserved in this capacity configuration. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.