pub struct InstanceSummary {
pub id: String,
pub availability_domain: String,
pub compartment_id: String,
pub instance_configuration_id: String,
pub region: String,
pub state: String,
pub time_created: DateTime<Utc>,
pub display_name: Option<String>,
pub fault_domain: Option<String>,
pub shape: Option<String>,
pub load_balancer_backends: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>,
}Expand description
Condensed instance data when listing instances in an instance pool.
Fields
id: StringThe OCID of the instance.
availability_domain: StringThe availability domain the instance is running in.
compartment_id: StringThe OCID of the compartment that contains the instance.
instance_configuration_id: StringThe OCID of the instance confgiuration used to create the instance.
region: StringThe region that contains the availability domain the instance is running in.
state: StringThe current state of the instance pool instance.
time_created: DateTime<Utc>The date and time the instance pool instance was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
fault_domain: Option<String>The fault domain the instance is running in.
shape: Option<String>The shape of an instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.
You can enumerate all available shapes by calling {@link #listShapes(ListShapesRequest) listShapes}.
load_balancer_backends: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>The load balancer backends that are configured for the instance pool instance.
Implementations
Sourceimpl InstanceSummary
impl InstanceSummary
Sourcepub fn new(required: InstanceSummaryRequired) -> Self
pub fn new(required: InstanceSummaryRequired) -> Self
Create a new InstanceSummary with required fields
Sourcepub fn set_availability_domain(self, value: String) -> Self
pub fn set_availability_domain(self, value: String) -> Self
Set availability_domain
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Sourcepub fn set_fault_domain(self, value: Option<String>) -> Self
pub fn set_fault_domain(self, value: Option<String>) -> Self
Set fault_domain
Sourcepub fn set_instance_configuration_id(self, value: String) -> Self
pub fn set_instance_configuration_id(self, value: String) -> Self
Set instance_configuration_id
Sourcepub fn set_region(self, value: String) -> Self
pub fn set_region(self, value: String) -> Self
Set region
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Sourcepub fn set_load_balancer_backends(
self,
value: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>,
) -> Self
pub fn set_load_balancer_backends( self, value: Option<Vec<InstancePoolInstanceLoadBalancerBackend>>, ) -> Self
Set load_balancer_backends
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Sourcepub fn with_fault_domain(self, value: impl Into<String>) -> Self
pub fn with_fault_domain(self, value: impl Into<String>) -> Self
Set fault_domain (unwraps Option)
Sourcepub fn with_shape(self, value: impl Into<String>) -> Self
pub fn with_shape(self, value: impl Into<String>) -> Self
Set shape (unwraps Option)
Sourcepub fn with_load_balancer_backends(
self,
value: Vec<InstancePoolInstanceLoadBalancerBackend>,
) -> Self
pub fn with_load_balancer_backends( self, value: Vec<InstancePoolInstanceLoadBalancerBackend>, ) -> Self
Set load_balancer_backends (unwraps Option)