pub struct InstanceSummaryRequired {
pub id: String,
pub availability_domain: String,
pub compartment_id: String,
pub instance_configuration_id: String,
pub region: String,
pub state: String,
pub time_created: DateTime<Utc>,
}Expand description
Required fields for InstanceSummary
Fields
id: StringThe OCID of the instance.
availability_domain: StringThe availability domain the instance is running in.
compartment_id: StringThe OCID of the compartment that contains the instance.
instance_configuration_id: StringThe OCID of the instance confgiuration used to create the instance.
region: StringThe region that contains the availability domain the instance is running in.
state: StringThe current state of the instance pool instance.
time_created: DateTime<Utc>The date and time the instance pool instance was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}