IPSecConnection

Struct IPSecConnection 

pub struct IPSecConnection {
Show 13 fields pub compartment_id: String, pub cpe_id: String, pub drg_id: String, pub id: String, pub lifecycle_state: IPSecConnectionLifecycleState, pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>, pub display_name: Option<String>, pub freeform_tags: Option<HashMap<String, String>>, pub cpe_local_identifier: Option<String>, pub cpe_local_identifier_type: Option<IPSecConnectionCpeLocalIdentifierType>, pub static_routes: Option<Vec<String>>, pub time_created: Option<DateTime<Utc>>, pub transport_type: Option<IPSecConnectionTransportType>,
}
A connection between a DRG and CPE. This connection consists of multiple IPSec tunnels. Creating this connection is one of the steps required when setting up a Site-to-Site VPN.

Important:* Each tunnel in an IPSec connection can use either static routing or BGP dynamic routing (see the {@link IPSecConnectionTunnel} object’s {@code routing} attribute). Originally only static routing was supported and every IPSec connection was required to have at least one static route configured. To maintain backward compatibility in the API when support for BPG dynamic routing was introduced, the API accepts an empty list of static routes if you configure both of the IPSec tunnels to use BGP dynamic routing. If you switch a tunnel’s routing from {@code BGP} to {@code STATIC}, you must first ensure that the IPSec connection is configured with at least one valid CIDR block static route. Oracle uses the IPSec connection’s static routes when routing a tunnel’s traffic only if that tunnel’s {@code routing} attribute = {@code STATIC}. Otherwise the static routes are ignored.

For more information about the workflow for setting up an IPSec connection, see Site-to-Site VPN Overview.

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.

Fields

compartment_id: String

The OCID of the compartment containing the IPSec connection.

cpe_id: String

The OCID of the {@link Cpe} object.

drg_id: String

The OCID of the DRG.

id: String

The IPSec connection’s Oracle ID (OCID).

lifecycle_state: IPSecConnectionLifecycleState

The IPSec connection’s current state.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

display_name: Option<String>

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

cpe_local_identifier: Option<String>

Your identifier for your CPE device. Can be either an IP address or a hostname (specifically, the fully qualified domain name (FQDN)). The type of identifier here must correspond to the value for {@code cpeLocalIdentifierType}.

If you don’t provide a value when creating the IPSec connection, the {@code ipAddress} attribute for the {@link Cpe} object specified by {@code cpeId} is used as the {@code cpeLocalIdentifier}.

For information about why you’d provide this value, see If Your CPE Is Behind a NAT Device.

Example IP address: {@code 10.0.3.3}

Example hostname: {@code cpe.example.com}

cpe_local_identifier_type: Option<IPSecConnectionCpeLocalIdentifierType>

The type of identifier for your CPE device. The value here must correspond to the value for {@code cpeLocalIdentifier}.

static_routes: Option<Vec<String>>

Static routes to the CPE. The CIDR must not be a multicast address or class E address.

Used for routing a given IPSec tunnel’s traffic only if the tunnel is using static routing. If you configure at least one tunnel to use static routing, then you must provide at least one valid static route. If you configure both tunnels to use BGP dynamic routing, you can provide an empty list for the static routes.

The CIDR can be either IPv4 or IPv6. IPv6 addressing is supported for all commercial and government regions. See IPv6 Addresses.

Example: {@code 10.0.1.0/24}

Example: {@code 2001:db8::/32}

time_created: Option<DateTime<Utc>>

The date and time the IPSec connection was created, in the format defined by RFC3339.

Example: {@code 2016-08-25T21:10:29.600Z}

transport_type: Option<IPSecConnectionTransportType>

The transport type used for the IPSec connection.

Implementations

Source

impl IPSecConnection

pub fn new(required: IPSecConnectionRequired) -> Self

Create a new IPSecConnection with required fields

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_cpe_id(self, value: String) -> Self

Set cpe_id

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_drg_id(self, value: String) -> Self

Set drg_id

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_lifecycle_state(self, value: IPSecConnectionLifecycleState) -> Self

Set lifecycle_state

pub fn set_cpe_local_identifier(self, value: Option<String>) -> Self

Set cpe_local_identifier

pub fn set_cpe_local_identifier_type( self, value: Option<IPSecConnectionCpeLocalIdentifierType>, ) -> Self

Set cpe_local_identifier_type

pub fn set_static_routes(self, value: Option<Vec<String>>) -> Self

Set static_routes

pub fn set_time_created(self, value: Option<DateTime<Utc>>) -> Self

Set time_created

pub fn set_transport_type( self, value: Option<IPSecConnectionTransportType>, ) -> Self

Set transport_type

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_cpe_local_identifier(self, value: impl Into<String>) -> Self

Set cpe_local_identifier (unwraps Option)

pub fn with_cpe_local_identifier_type( self, value: IPSecConnectionCpeLocalIdentifierType, ) -> Self

Set cpe_local_identifier_type (unwraps Option)

pub fn with_static_routes(self, value: Vec<String>) -> Self

Set static_routes (unwraps Option)

pub fn with_time_created(self, value: DateTime<Utc>) -> Self

Set time_created (unwraps Option)

pub fn with_transport_type(self, value: IPSecConnectionTransportType) -> Self

Set transport_type (unwraps Option)