pub struct LaunchOptions {
pub boot_volume_type: Option<LaunchOptionsBootVolumeType>,
pub firmware: Option<LaunchOptionsFirmware>,
pub network_type: Option<LaunchOptionsNetworkType>,
pub remote_data_volume_type: Option<LaunchOptionsRemoteDataVolumeType>,
pub is_pv_encryption_in_transit_enabled: Option<bool>,
pub is_consistent_volume_naming_enabled: Option<bool>,
}Expand description
Options for tuning the compatibility and performance of VM shapes. The values that you specify override any default values.
Fields
boot_volume_type: Option<LaunchOptionsBootVolumeType>Emulation type for the boot volume. * {@code ISCSI} - ISCSI attached block storage device. * {@code SCSI} - Emulated SCSI disk. * {@code IDE} - Emulated IDE disk. * {@code VFIO} - Direct attached Virtual Function storage. This is the default option for local data volumes on platform images. * {@code PARAVIRTUALIZED} - Paravirtualized disk. This is the default for boot volumes and remote block storage volumes on platform images.
firmware: Option<LaunchOptionsFirmware>Firmware used to boot VM. Select the option that matches your operating system. * {@code BIOS} - Boot VM using BIOS style firmware. This is compatible with both 32 bit and 64 bit operating systems that boot using MBR style bootloaders. * {@code UEFI_64} - Boot VM using UEFI style firmware compatible with 64 bit operating systems. This is the default for platform images.
network_type: Option<LaunchOptionsNetworkType>Emulation type for the physical network interface card (NIC). * {@code E1000} - Emulated Gigabit ethernet controller. Compatible with Linux e1000 network driver. * {@code VFIO} - Direct attached Virtual Function network controller. This is the networking type when you launch an instance using hardware-assisted (SR-IOV) networking. * {@code PARAVIRTUALIZED} - VM instances launch with paravirtualized devices using VirtIO drivers.
remote_data_volume_type: Option<LaunchOptionsRemoteDataVolumeType>Emulation type for volume. * {@code ISCSI} - ISCSI attached block storage device. * {@code SCSI} - Emulated SCSI disk. * {@code IDE} - Emulated IDE disk. * {@code VFIO} - Direct attached Virtual Function storage. This is the default option for local data volumes on platform images. * {@code PARAVIRTUALIZED} - Paravirtualized disk. This is the default for boot volumes and remote block storage volumes on platform images.
is_pv_encryption_in_transit_enabled: Option<bool>Deprecated. Instead use {@code isPvEncryptionInTransitEnabled} in {@link #launchInstanceDetails(LaunchInstanceDetailsRequest) launchInstanceDetails}.
is_consistent_volume_naming_enabled: Option<bool>Whether to enable consistent volume naming feature. Defaults to false.
Implementations
Sourceimpl LaunchOptions
impl LaunchOptions
Sourcepub fn set_boot_volume_type(
self,
value: Option<LaunchOptionsBootVolumeType>,
) -> Self
pub fn set_boot_volume_type( self, value: Option<LaunchOptionsBootVolumeType>, ) -> Self
Set boot_volume_type
Sourcepub fn set_firmware(self, value: Option<LaunchOptionsFirmware>) -> Self
pub fn set_firmware(self, value: Option<LaunchOptionsFirmware>) -> Self
Set firmware
Sourcepub fn set_network_type(self, value: Option<LaunchOptionsNetworkType>) -> Self
pub fn set_network_type(self, value: Option<LaunchOptionsNetworkType>) -> Self
Set network_type
Sourcepub fn set_remote_data_volume_type(
self,
value: Option<LaunchOptionsRemoteDataVolumeType>,
) -> Self
pub fn set_remote_data_volume_type( self, value: Option<LaunchOptionsRemoteDataVolumeType>, ) -> Self
Set remote_data_volume_type
Sourcepub fn set_is_pv_encryption_in_transit_enabled(
self,
value: Option<bool>,
) -> Self
pub fn set_is_pv_encryption_in_transit_enabled( self, value: Option<bool>, ) -> Self
Set is_pv_encryption_in_transit_enabled
Sourcepub fn set_is_consistent_volume_naming_enabled(
self,
value: Option<bool>,
) -> Self
pub fn set_is_consistent_volume_naming_enabled( self, value: Option<bool>, ) -> Self
Set is_consistent_volume_naming_enabled
Sourcepub fn with_boot_volume_type(self, value: LaunchOptionsBootVolumeType) -> Self
pub fn with_boot_volume_type(self, value: LaunchOptionsBootVolumeType) -> Self
Set boot_volume_type (unwraps Option)
Sourcepub fn with_firmware(self, value: LaunchOptionsFirmware) -> Self
pub fn with_firmware(self, value: LaunchOptionsFirmware) -> Self
Set firmware (unwraps Option)
Sourcepub fn with_network_type(self, value: LaunchOptionsNetworkType) -> Self
pub fn with_network_type(self, value: LaunchOptionsNetworkType) -> Self
Set network_type (unwraps Option)
Sourcepub fn with_remote_data_volume_type(
self,
value: LaunchOptionsRemoteDataVolumeType,
) -> Self
pub fn with_remote_data_volume_type( self, value: LaunchOptionsRemoteDataVolumeType, ) -> Self
Set remote_data_volume_type (unwraps Option)
Sourcepub fn with_is_pv_encryption_in_transit_enabled(self, value: bool) -> Self
pub fn with_is_pv_encryption_in_transit_enabled(self, value: bool) -> Self
Set is_pv_encryption_in_transit_enabled (unwraps Option)
Sourcepub fn with_is_consistent_volume_naming_enabled(self, value: bool) -> Self
pub fn with_is_consistent_volume_naming_enabled(self, value: bool) -> Self
Set is_consistent_volume_naming_enabled (unwraps Option)