pub enum MacsecEncryptionCipher {
Aes128Gcm,
Aes128GcmXpn,
Aes256Gcm,
Aes256GcmXpn,
UnknownValue,
}Expand description
Type of encryption cipher suite to use for the MACsec connection.
Variants
Aes128Gcm
Aes128GcmXpn
Aes256Gcm
Aes256GcmXpn
UnknownValue
This value is used if a service returns a value for this enum that is not recognized by this version of the SDK.