RouteTable

Struct RouteTable 

pub struct RouteTable {
    pub compartment_id: String,
    pub id: String,
    pub lifecycle_state: RouteTableLifecycleState,
    pub route_rules: Vec<RouteRule>,
    pub vcn_id: String,
    pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
    pub display_name: Option<String>,
    pub freeform_tags: Option<HashMap<String, String>>,
    pub time_created: Option<DateTime<Utc>>,
}
A collection of {@code RouteRule} objects, which are used to route packets based on destination IP to a particular network entity. For more information, see Overview of the Networking Service.

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.

Fields

compartment_id: String

The OCID of the compartment containing the route table.

id: String

The route table’s Oracle ID (OCID).

lifecycle_state: RouteTableLifecycleState

The route table’s current state.

route_rules: Vec<RouteRule>

The collection of rules for routing destination IPs to network devices.

vcn_id: String

The OCID of the VCN the route table list belongs to.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

display_name: Option<String>

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

time_created: Option<DateTime<Utc>>

The date and time the route table was created, in the format defined by RFC3339.

Example: {@code 2016-08-25T21:10:29.600Z}

Implementations

Source

impl RouteTable

pub fn new(required: RouteTableRequired) -> Self

Create a new RouteTable with required fields

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_display_name(self, value: Option<String>) -> Self

Set display_name

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_lifecycle_state(self, value: RouteTableLifecycleState) -> Self

Set lifecycle_state

pub fn set_route_rules(self, value: Vec<RouteRule>) -> Self

Set route_rules

pub fn set_time_created(self, value: Option<DateTime<Utc>>) -> Self

Set time_created

pub fn set_vcn_id(self, value: String) -> Self

Set vcn_id

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_display_name(self, value: impl Into<String>) -> Self

Set display_name (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_time_created(self, value: DateTime<Utc>) -> Self

Set time_created (unwraps Option)