pub enum SecurityRuleDirection {
Egress,
Ingress,
UnknownValue,
}Variants
Egress
Ingress
UnknownValue
This value is used if a service returns a value for this enum that is not recognized by this version of the SDK.