pub struct Service {
pub cidr_block: String,
pub description: String,
pub id: String,
pub name: String,
}Expand description
An object that represents one or multiple Oracle services that you can enable for a {@link ServiceGateway}. In the User Guide topic Access to Oracle Services: Service Gateway, the term service CIDR label is used to refer to the string that represents the regional public IP address ranges of the Oracle service or services covered by a given {@code Service} object. That unique string is the value of the {@code Service} object’s {@code cidrBlock} attribute.
Fields
cidr_block: StringA string that represents the regional public IP address ranges for the Oracle service or services covered by this {@code Service} object. Also known as the {@code Service} object’s service CIDR label.
When you set up a route rule to route traffic to the service gateway, use this value as the rule’s destination. See {@link RouteTable}. Also, when you set up a security list rule to cover traffic with the service gateway, use the {@code cidrBlock} value as the rule’s destination (for an egress rule) or the source (for an ingress rule). See {@link SecurityList}.
Example: {@code oci-phx-objectstorage}
description: StringDescription of the Oracle service or services covered by this {@code Service} object.
Example: {@code OCI PHX Object Storage}
id: StringThe {@code Service} object’s OCID.
name: StringName of the {@code Service} object. This name can change and is not guaranteed to be unique.
Example: {@code OCI PHX Object Storage}
Implementations
Sourceimpl Service
impl Service
Sourcepub fn new(required: ServiceRequired) -> Self
pub fn new(required: ServiceRequired) -> Self
Create a new Service with required fields
Sourcepub fn set_cidr_block(self, value: String) -> Self
pub fn set_cidr_block(self, value: String) -> Self
Set cidr_block
Sourcepub fn set_description(self, value: String) -> Self
pub fn set_description(self, value: String) -> Self
Set description