UpdateLaunchOptions

Struct UpdateLaunchOptions 

pub struct UpdateLaunchOptions {
    pub boot_volume_type: Option<UpdateLaunchOptionsBootVolumeType>,
    pub network_type: Option<UpdateLaunchOptionsNetworkType>,
    pub is_pv_encryption_in_transit_enabled: Option<bool>,
}
Options for tuning the compatibility and performance of VM shapes.

Fields

boot_volume_type: Option<UpdateLaunchOptionsBootVolumeType>

Emulation type for the boot volume. * {@code ISCSI} - ISCSI attached block storage device. * {@code PARAVIRTUALIZED} - Paravirtualized disk. This is the default for boot volumes and remote block storage volumes on platform images.

Before you change the boot volume attachment type, detach all block volumes and VNICs except for the boot volume and the primary VNIC.

If the instance is running when you change the boot volume attachment type, it will be rebooted.

Note:* Some instances might not function properly if you change the boot volume attachment type. After the instance reboots and is running, connect to it. If the connection fails or the OS doesn’t behave as expected, the changes are not supported. Revert the instance to the original boot volume attachment type.

network_type: Option<UpdateLaunchOptionsNetworkType>

Emulation type for the physical network interface card (NIC). * {@code VFIO} - Direct attached Virtual Function network controller. This is the networking type when you launch an instance using hardware-assisted (SR-IOV) networking. * {@code PARAVIRTUALIZED} - VM instances launch with paravirtualized devices using VirtIO drivers.

Before you change the networking type, detach all VNICs and block volumes except for the primary VNIC and the boot volume.

The image must have paravirtualized drivers installed. For more information, see Editing an Instance.

If the instance is running when you change the network type, it will be rebooted.

Note:* Some instances might not function properly if you change the networking type. After the instance reboots and is running, connect to it. If the connection fails or the OS doesn’t behave as expected, the changes are not supported. Revert the instance to the original networking type.

is_pv_encryption_in_transit_enabled: Option<bool>

Whether to enable in-transit encryption for the volume’s paravirtualized attachment. To enable in-transit encryption for block volumes and boot volumes, this field must be set to {@code true}.

Data in transit is transferred over an internal and highly secure network. If you have specific compliance requirements related to the encryption of the data while it is moving between the instance and the boot volume or the block volume, you can enable in-transit encryption. In-transit encryption is not enabled by default.

All boot volumes and block volumes are encrypted at rest.

For more information, see Block Volume Encryption.

Implementations

Source

impl UpdateLaunchOptions

pub fn new() -> Self

Create a new UpdateLaunchOptions

pub fn set_boot_volume_type( self, value: Option<UpdateLaunchOptionsBootVolumeType>, ) -> Self

Set boot_volume_type

pub fn set_network_type( self, value: Option<UpdateLaunchOptionsNetworkType>, ) -> Self

Set network_type

pub fn set_is_pv_encryption_in_transit_enabled( self, value: Option<bool>, ) -> Self

Set is_pv_encryption_in_transit_enabled

pub fn with_boot_volume_type( self, value: UpdateLaunchOptionsBootVolumeType, ) -> Self

Set boot_volume_type (unwraps Option)

pub fn with_network_type(self, value: UpdateLaunchOptionsNetworkType) -> Self

Set network_type (unwraps Option)

pub fn with_is_pv_encryption_in_transit_enabled(self, value: bool) -> Self

Set is_pv_encryption_in_transit_enabled (unwraps Option)