pub struct UpdateMacsecKey {
pub connectivity_association_name_secret_id: String,
pub connectivity_association_name_secret_version: i64,
pub connectivity_association_key_secret_id: String,
pub connectivity_association_key_secret_version: i64,
}Expand description
An object defining the OCID of the Secret held in Vault that represent the MACsec key.
Fields
connectivity_association_name_secret_id: StringSecret OCID containing the Connectivity Association Key Name (CKN) of this MACsec key.
connectivity_association_name_secret_version: i64The secret version of the connectivity association name secret in Vault. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
connectivity_association_key_secret_id: StringSecret OCID containing the Connectivity Association Key (CAK) of this MACsec key.
connectivity_association_key_secret_version: i64The secret version of the connectivityAssociationKey secret in Vault. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
Implementations
Sourceimpl UpdateMacsecKey
impl UpdateMacsecKey
Sourcepub fn new(required: UpdateMacsecKeyRequired) -> Self
pub fn new(required: UpdateMacsecKeyRequired) -> Self
Create a new UpdateMacsecKey with required fields
Sourcepub fn set_connectivity_association_name_secret_id(self, value: String) -> Self
pub fn set_connectivity_association_name_secret_id(self, value: String) -> Self
Set connectivity_association_name_secret_id
Sourcepub fn set_connectivity_association_name_secret_version(
self,
value: i64,
) -> Self
pub fn set_connectivity_association_name_secret_version( self, value: i64, ) -> Self
Set connectivity_association_name_secret_version
Sourcepub fn set_connectivity_association_key_secret_id(self, value: String) -> Self
pub fn set_connectivity_association_key_secret_id(self, value: String) -> Self
Set connectivity_association_key_secret_id
Sourcepub fn set_connectivity_association_key_secret_version(self, value: i64) -> Self
pub fn set_connectivity_association_key_secret_version(self, value: i64) -> Self
Set connectivity_association_key_secret_version