VolumeBackup

Struct VolumeBackup 

pub struct VolumeBackup {
Show 19 fields pub compartment_id: String, pub display_name: String, pub id: String, pub lifecycle_state: VolumeBackupLifecycleState, pub time_created: DateTime<Utc>, pub type: VolumeBackupType, pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>, pub system_tags: Option<HashMap<String, HashMap<String, Value>>>, pub expiration_time: Option<DateTime<Utc>>, pub freeform_tags: Option<HashMap<String, String>>, pub kms_key_id: Option<String>, pub size_in_gbs: Option<i64>, pub size_in_mbs: Option<i64>, pub source_type: Option<VolumeBackupSourceType>, pub source_volume_backup_id: Option<String>, pub time_request_received: Option<DateTime<Utc>>, pub unique_size_in_gbs: Option<i64>, pub unique_size_in_mbs: Option<i64>, pub volume_id: Option<String>,
}
A point-in-time copy of a volume that can then be used to create a new block volume or recover a block volume. For more information, see Overview of Cloud Volume Storage.

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.

Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Fields

compartment_id: String

The OCID of the compartment that contains the volume backup.

display_name: String

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

id: String

The OCID of the volume backup.

lifecycle_state: VolumeBackupLifecycleState

The current state of a volume backup.

time_created: DateTime<Utc>

The date and time the volume backup was created. This is the time the actual point-in-time image of the volume data was taken. Format defined by RFC3339.

type: VolumeBackupType

The type of a volume backup.

defined_tags: Option<HashMap<String, HashMap<String, Value>>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.

Example: {@code {"Operations": {"CostCenter": "42"}}}

system_tags: Option<HashMap<String, HashMap<String, Value>>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: {@code {"foo-namespace": {"bar-key": "value"}}}

expiration_time: Option<DateTime<Utc>>

The date and time the volume backup will expire and be automatically deleted. Format defined by RFC3339. This parameter will always be present for backups that were created automatically by a scheduled-backup policy. For manually created backups, it will be absent, signifying that there is no expiration time and the backup will last forever until manually deleted.

freeform_tags: Option<HashMap<String, String>>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.

Example: {@code {"Department": "Finance"}}

kms_key_id: Option<String>

The OCID of the Vault service key which is the master encryption key for the volume backup. For more information about the Vault service and encryption keys, see Overview of Vault service and Using Keys.

size_in_gbs: Option<i64>

The size of the volume, in GBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

size_in_mbs: Option<i64>

The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Please use sizeInGBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

source_type: Option<VolumeBackupSourceType>

Specifies whether the backup was created manually, or via scheduled backup policy.

source_volume_backup_id: Option<String>

The OCID of the source volume backup.

time_request_received: Option<DateTime<Utc>>

The date and time the request to create the volume backup was received. Format defined by [RFC3339]https://tools.ietf.org/html/rfc3339.

unique_size_in_gbs: Option<i64>

The size used by the backup, in GBs. It is typically smaller than sizeInGBs, depending on the space consumed on the volume and whether the backup is full or incremental. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

unique_size_in_mbs: Option<i64>

The size used by the backup, in MBs. It is typically smaller than sizeInMBs, depending on the space consumed on the volume and whether the backup is full or incremental. This field is deprecated. Please use uniqueSizeInGBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.

volume_id: Option<String>

The OCID of the volume.

Implementations

Source

impl VolumeBackup

pub fn new(required: VolumeBackupRequired) -> Self

Create a new VolumeBackup with required fields

pub fn set_compartment_id(self, value: String) -> Self

Set compartment_id

pub fn set_defined_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set defined_tags

pub fn set_system_tags( self, value: Option<HashMap<String, HashMap<String, Value>>>, ) -> Self

Set system_tags

pub fn set_display_name(self, value: String) -> Self

Set display_name

pub fn set_expiration_time(self, value: Option<DateTime<Utc>>) -> Self

Set expiration_time

pub fn set_freeform_tags(self, value: Option<HashMap<String, String>>) -> Self

Set freeform_tags

pub fn set_id(self, value: String) -> Self

Set id

pub fn set_kms_key_id(self, value: Option<String>) -> Self

Set kms_key_id

pub fn set_lifecycle_state(self, value: VolumeBackupLifecycleState) -> Self

Set lifecycle_state

pub fn set_size_in_gbs(self, value: Option<i64>) -> Self

Set size_in_gbs

pub fn set_size_in_mbs(self, value: Option<i64>) -> Self

Set size_in_mbs

pub fn set_source_type(self, value: Option<VolumeBackupSourceType>) -> Self

Set source_type

pub fn set_source_volume_backup_id(self, value: Option<String>) -> Self

Set source_volume_backup_id

pub fn set_time_created(self, value: DateTime<Utc>) -> Self

Set time_created

pub fn set_time_request_received(self, value: Option<DateTime<Utc>>) -> Self

Set time_request_received

pub fn set_type(self, value: VolumeBackupType) -> Self

Set r#type

pub fn set_unique_size_in_gbs(self, value: Option<i64>) -> Self

Set unique_size_in_gbs

pub fn set_unique_size_in_mbs(self, value: Option<i64>) -> Self

Set unique_size_in_mbs

pub fn set_volume_id(self, value: Option<String>) -> Self

Set volume_id

pub fn with_defined_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set defined_tags (unwraps Option)

pub fn with_system_tags( self, value: HashMap<String, HashMap<String, Value>>, ) -> Self

Set system_tags (unwraps Option)

pub fn with_expiration_time(self, value: DateTime<Utc>) -> Self

Set expiration_time (unwraps Option)

pub fn with_freeform_tags(self, value: HashMap<String, String>) -> Self

Set freeform_tags (unwraps Option)

pub fn with_kms_key_id(self, value: impl Into<String>) -> Self

Set kms_key_id (unwraps Option)

pub fn with_size_in_gbs(self, value: i64) -> Self

Set size_in_gbs (unwraps Option)

pub fn with_size_in_mbs(self, value: i64) -> Self

Set size_in_mbs (unwraps Option)

pub fn with_source_type(self, value: VolumeBackupSourceType) -> Self

Set source_type (unwraps Option)

pub fn with_source_volume_backup_id(self, value: impl Into<String>) -> Self

Set source_volume_backup_id (unwraps Option)

pub fn with_time_request_received(self, value: DateTime<Utc>) -> Self

Set time_request_received (unwraps Option)

pub fn with_unique_size_in_gbs(self, value: i64) -> Self

Set unique_size_in_gbs (unwraps Option)

pub fn with_unique_size_in_mbs(self, value: i64) -> Self

Set unique_size_in_mbs (unwraps Option)

pub fn with_volume_id(self, value: impl Into<String>) -> Self

Set volume_id (unwraps Option)