pub struct VolumeBackupRequired {
pub compartment_id: String,
pub display_name: String,
pub id: String,
pub lifecycle_state: VolumeBackupLifecycleState,
pub time_created: DateTime<Utc>,
pub type: VolumeBackupType,
}Expand description
Required fields for VolumeBackup
Fields
compartment_id: StringThe OCID of the compartment that contains the volume backup.
display_name: StringA user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
id: StringThe OCID of the volume backup.
lifecycle_state: VolumeBackupLifecycleStateThe current state of a volume backup.
time_created: DateTime<Utc>The date and time the volume backup was created. This is the time the actual point-in-time image of the volume data was taken. Format defined by RFC3339.
type: VolumeBackupTypeThe type of a volume backup.