pub struct AttachVolumeRequest {
pub attach_volume_details: AttachServiceDeterminedVolumeDetails,
pub opc_retry_token: Option<String>,
}Fields
attach_volume_details: AttachServiceDeterminedVolumeDetailsAttach volume request
opc_retry_token: Option<String>A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).
Implementations
Sourceimpl AttachVolumeRequest
impl AttachVolumeRequest
Sourcepub fn new(required: AttachVolumeRequestRequired) -> Self
pub fn new(required: AttachVolumeRequestRequired) -> Self
Create a new AttachVolumeRequest with required fields
Sourcepub fn set_attach_volume_details(
self,
value: AttachServiceDeterminedVolumeDetails,
) -> Self
pub fn set_attach_volume_details( self, value: AttachServiceDeterminedVolumeDetails, ) -> Self
Set attach_volume_details
Sourcepub fn set_opc_retry_token(self, value: Option<String>) -> Self
pub fn set_opc_retry_token(self, value: Option<String>) -> Self
Set opc_retry_token
Sourcepub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
Set opc_retry_token (unwraps Option)