CreateImageRequest

Struct CreateImageRequest 

pub struct CreateImageRequest {
    pub create_image_details: CreateImageDetails,
    pub opc_retry_token: Option<String>,
}

Fields

create_image_details: CreateImageDetails

Image creation details

opc_retry_token: Option<String>

A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).

Implementations

Source

impl CreateImageRequest

pub fn new(required: CreateImageRequestRequired) -> Self

Create a new CreateImageRequest with required fields

pub fn set_create_image_details(self, value: CreateImageDetails) -> Self

Set create_image_details

pub fn set_opc_retry_token(self, value: Option<String>) -> Self

Set opc_retry_token

pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self

Set opc_retry_token (unwraps Option)