pub struct CreateVcnRequest {
pub create_vcn_details: CreateVcnDetails,
pub opc_retry_token: Option<String>,
}Fields
create_vcn_details: CreateVcnDetailsDetails for creating a new VCN.
opc_retry_token: Option<String>A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).
Implementations
Sourceimpl CreateVcnRequest
impl CreateVcnRequest
Sourcepub fn new(required: CreateVcnRequestRequired) -> Self
pub fn new(required: CreateVcnRequestRequired) -> Self
Create a new CreateVcnRequest with required fields
Sourcepub fn set_create_vcn_details(self, value: CreateVcnDetails) -> Self
pub fn set_create_vcn_details(self, value: CreateVcnDetails) -> Self
Set create_vcn_details
Sourcepub fn set_opc_retry_token(self, value: Option<String>) -> Self
pub fn set_opc_retry_token(self, value: Option<String>) -> Self
Set opc_retry_token
Sourcepub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
Set opc_retry_token (unwraps Option)