CreateVlanRequest

Struct CreateVlanRequest 

pub struct CreateVlanRequest {
    pub create_vlan_details: CreateVlanDetails,
    pub opc_retry_token: Option<String>,
    pub opc_request_id: Option<String>,
}

Fields

create_vlan_details: CreateVlanDetails

Details for creating a VLAN

opc_retry_token: Option<String>

A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).

opc_request_id: Option<String>

Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

Implementations

Source

impl CreateVlanRequest

pub fn new(required: CreateVlanRequestRequired) -> Self

Create a new CreateVlanRequest with required fields

pub fn set_create_vlan_details(self, value: CreateVlanDetails) -> Self

Set create_vlan_details

pub fn set_opc_retry_token(self, value: Option<String>) -> Self

Set opc_retry_token

pub fn set_opc_request_id(self, value: Option<String>) -> Self

Set opc_request_id

pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self

Set opc_retry_token (unwraps Option)

pub fn with_opc_request_id(self, value: impl Into<String>) -> Self

Set opc_request_id (unwraps Option)