pub struct CreateVtapRequest {
pub create_vtap_details: CreateVtapDetails,
pub opc_retry_token: Option<String>,
pub opc_request_id: Option<String>,
}Fields
create_vtap_details: CreateVtapDetailsDetails used to create a VTAP.
opc_retry_token: Option<String>A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).
opc_request_id: Option<String>Unique identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.
Implementations
Sourceimpl CreateVtapRequest
impl CreateVtapRequest
Sourcepub fn new(required: CreateVtapRequestRequired) -> Self
pub fn new(required: CreateVtapRequestRequired) -> Self
Create a new CreateVtapRequest with required fields
Sourcepub fn set_create_vtap_details(self, value: CreateVtapDetails) -> Self
pub fn set_create_vtap_details(self, value: CreateVtapDetails) -> Self
Set create_vtap_details
Sourcepub fn set_opc_retry_token(self, value: Option<String>) -> Self
pub fn set_opc_retry_token(self, value: Option<String>) -> Self
Set opc_retry_token
Sourcepub fn set_opc_request_id(self, value: Option<String>) -> Self
pub fn set_opc_request_id(self, value: Option<String>) -> Self
Set opc_request_id
Sourcepub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
Set opc_retry_token (unwraps Option)
Sourcepub fn with_opc_request_id(self, value: impl Into<String>) -> Self
pub fn with_opc_request_id(self, value: impl Into<String>) -> Self
Set opc_request_id (unwraps Option)