DeleteImageRequest

Struct DeleteImageRequest 

pub struct DeleteImageRequest {
    pub image_id: String,
    pub if_match: Option<String>,
}

Fields

image_id: String

The OCID of the image.

if_match: Option<String>

For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

Implementations

Source

impl DeleteImageRequest

pub fn new(required: DeleteImageRequestRequired) -> Self

Create a new DeleteImageRequest with required fields

pub fn set_image_id(self, value: String) -> Self

Set image_id

pub fn set_if_match(self, value: Option<String>) -> Self

Set if_match

pub fn with_if_match(self, value: impl Into<String>) -> Self

Set if_match (unwraps Option)