pub struct DeleteSubnetRequest {
pub subnet_id: String,
pub if_match: Option<String>,
}Fields
subnet_id: StringSpecify the OCID of the subnet.
if_match: Option<String>For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.
Implementations
Sourceimpl DeleteSubnetRequest
impl DeleteSubnetRequest
Sourcepub fn new(required: DeleteSubnetRequestRequired) -> Self
pub fn new(required: DeleteSubnetRequestRequired) -> Self
Create a new DeleteSubnetRequest with required fields
Sourcepub fn set_subnet_id(self, value: String) -> Self
pub fn set_subnet_id(self, value: String) -> Self
Set subnet_id
Sourcepub fn set_if_match(self, value: Option<String>) -> Self
pub fn set_if_match(self, value: Option<String>) -> Self
Set if_match
Sourcepub fn with_if_match(self, value: impl Into<String>) -> Self
pub fn with_if_match(self, value: impl Into<String>) -> Self
Set if_match (unwraps Option)