DeleteVolumeRequest

Struct DeleteVolumeRequest 

pub struct DeleteVolumeRequest {
    pub volume_id: String,
    pub if_match: Option<String>,
}

Fields

volume_id: String

The OCID of the volume.

if_match: Option<String>

For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

Implementations

Source

impl DeleteVolumeRequest

pub fn new(required: DeleteVolumeRequestRequired) -> Self

Create a new DeleteVolumeRequest with required fields

pub fn set_volume_id(self, value: String) -> Self

Set volume_id

pub fn set_if_match(self, value: Option<String>) -> Self

Set if_match

pub fn with_if_match(self, value: impl Into<String>) -> Self

Set if_match (unwraps Option)