InstanceActionRequest

Struct InstanceActionRequest 

pub struct InstanceActionRequest {
    pub instance_id: String,
    pub action: String,
    pub opc_retry_token: Option<String>,
    pub if_match: Option<String>,
    pub instance_power_action_details: Option<ResetActionDetails>,
}

Fields

instance_id: String

The OCID of the instance.

action: String

The action to perform on the instance.

opc_retry_token: Option<String>

A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).

if_match: Option<String>

For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

instance_power_action_details: Option<ResetActionDetails>

Instance Power Action details

Implementations

Source

impl InstanceActionRequest

pub fn new(required: InstanceActionRequestRequired) -> Self

Create a new InstanceActionRequest with required fields

pub fn set_instance_id(self, value: String) -> Self

Set instance_id

pub fn set_action(self, value: String) -> Self

Set action

pub fn set_opc_retry_token(self, value: Option<String>) -> Self

Set opc_retry_token

pub fn set_if_match(self, value: Option<String>) -> Self

Set if_match

pub fn set_instance_power_action_details( self, value: Option<ResetActionDetails>, ) -> Self

Set instance_power_action_details

pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self

Set opc_retry_token (unwraps Option)

pub fn with_if_match(self, value: impl Into<String>) -> Self

Set if_match (unwraps Option)

pub fn with_instance_power_action_details( self, value: ResetActionDetails, ) -> Self

Set instance_power_action_details (unwraps Option)