pub struct UpdateInstanceRequest {
pub instance_id: String,
pub update_instance_details: UpdateInstanceDetails,
pub opc_retry_token: Option<String>,
pub if_match: Option<String>,
}Fields
instance_id: StringThe OCID of the instance.
update_instance_details: UpdateInstanceDetailsUpdate instance fields
opc_retry_token: Option<String>A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).
if_match: Option<String>For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.
Implementations
Sourceimpl UpdateInstanceRequest
impl UpdateInstanceRequest
Sourcepub fn new(required: UpdateInstanceRequestRequired) -> Self
pub fn new(required: UpdateInstanceRequestRequired) -> Self
Create a new UpdateInstanceRequest with required fields
Sourcepub fn set_instance_id(self, value: String) -> Self
pub fn set_instance_id(self, value: String) -> Self
Set instance_id
Sourcepub fn set_update_instance_details(self, value: UpdateInstanceDetails) -> Self
pub fn set_update_instance_details(self, value: UpdateInstanceDetails) -> Self
Set update_instance_details
Sourcepub fn set_opc_retry_token(self, value: Option<String>) -> Self
pub fn set_opc_retry_token(self, value: Option<String>) -> Self
Set opc_retry_token
Sourcepub fn set_if_match(self, value: Option<String>) -> Self
pub fn set_if_match(self, value: Option<String>) -> Self
Set if_match
Sourcepub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
Set opc_retry_token (unwraps Option)
Sourcepub fn with_if_match(self, value: impl Into<String>) -> Self
pub fn with_if_match(self, value: impl Into<String>) -> Self
Set if_match (unwraps Option)