UpdateSubnetRequest

Struct UpdateSubnetRequest 

pub struct UpdateSubnetRequest {
    pub subnet_id: String,
    pub update_subnet_details: UpdateSubnetDetails,
    pub if_match: Option<String>,
}

Fields

subnet_id: String

Specify the OCID of the subnet.

update_subnet_details: UpdateSubnetDetails

Details object for updating a subnet.

if_match: Option<String>

For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

Implementations

Source

impl UpdateSubnetRequest

pub fn new(required: UpdateSubnetRequestRequired) -> Self

Create a new UpdateSubnetRequest with required fields

pub fn set_subnet_id(self, value: String) -> Self

Set subnet_id

pub fn set_update_subnet_details(self, value: UpdateSubnetDetails) -> Self

Set update_subnet_details

pub fn set_if_match(self, value: Option<String>) -> Self

Set if_match

pub fn with_if_match(self, value: impl Into<String>) -> Self

Set if_match (unwraps Option)