pub struct BootVolume {Show 22 fields
pub availability_domain: String,
pub compartment_id: String,
pub id: String,
pub lifecycle_state: BootVolumeLifecycleState,
pub size_in_mbs: i64,
pub time_created: DateTime<Utc>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub system_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub display_name: Option<String>,
pub freeform_tags: Option<HashMap<String, String>>,
pub image_id: Option<String>,
pub is_hydrated: Option<bool>,
pub cluster_placement_group_id: Option<String>,
pub vpus_per_gb: Option<i64>,
pub size_in_gbs: Option<i64>,
pub source_details: Option<BootVolumeSourceFromBootVolumeBackupDetails>,
pub volume_group_id: Option<String>,
pub kms_key_id: Option<String>,
pub is_auto_tune_enabled: Option<bool>,
pub auto_tuned_vpus_per_gb: Option<i64>,
pub boot_volume_replicas: Option<Vec<BootVolumeReplicaInfo>>,
pub autotune_policies: Option<Vec<AutotunePolicy>>,
}Expand description
A detachable boot volume device that contains the image used to boot a Compute instance. For more information, see Overview of Boot Volumes.
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.
Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Fields
availability_domain: StringThe availability domain of the boot volume.
Example: {@code Uocm:PHX-AD-1}
compartment_id: StringThe OCID of the compartment that contains the boot volume.
id: StringThe boot volume’s Oracle ID (OCID).
lifecycle_state: BootVolumeLifecycleStateThe current state of a boot volume.
size_in_mbs: i64The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Please use sizeInGBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
time_created: DateTime<Utc>The date and time the boot volume was created. Format defined by RFC3339.
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
System tags for this resource. Each key is predefined and scoped to a namespace. Example: {@code {"foo-namespace": {"bar-key": "value"}}}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
image_id: Option<String>The image OCID used to create the boot volume.
is_hydrated: Option<bool>Specifies whether the boot volume’s data has finished copying from the source boot volume or boot volume backup.
cluster_placement_group_id: Option<String>The clusterPlacementGroup Id of the volume for volume placement.
vpus_per_gb: Option<i64>The number of volume performance units (VPUs) that will be applied to this boot volume per GB, representing the Block Volume service’s elastic performance options. See Block Volume Performance Levels for more information.
Allowed values:
{@code 10}: Represents Balanced option.
{@code 20}: Represents Higher Performance option.
{@code 30}-{@code 120}: Represents the Ultra High Performance option.
For performance autotune enabled volumes, it would be the Default(Minimum) VPUs/GB. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
size_in_gbs: Option<i64>The size of the boot volume in GBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
source_details: Option<BootVolumeSourceFromBootVolumeBackupDetails>volume_group_id: Option<String>The OCID of the source volume group.
kms_key_id: Option<String>The OCID of the Vault service master encryption key assigned to the boot volume.
is_auto_tune_enabled: Option<bool>Specifies whether the auto-tune performance is enabled for this boot volume. This field is deprecated. Use the {@code DetachedVolumeAutotunePolicy} instead to enable the volume for detached autotune.
auto_tuned_vpus_per_gb: Option<i64>The number of Volume Performance Units per GB that this boot volume is effectively tuned to. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
boot_volume_replicas: Option<Vec<BootVolumeReplicaInfo>>The list of boot volume replicas of this boot volume
autotune_policies: Option<Vec<AutotunePolicy>>The list of autotune policies enabled for this volume.
Implementations
Sourceimpl BootVolume
impl BootVolume
Sourcepub fn new(required: BootVolumeRequired) -> Self
pub fn new(required: BootVolumeRequired) -> Self
Create a new BootVolume with required fields
Sourcepub fn set_availability_domain(self, value: String) -> Self
pub fn set_availability_domain(self, value: String) -> Self
Set availability_domain
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Set defined_tags
Set system_tags
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Set freeform_tags
Sourcepub fn set_image_id(self, value: Option<String>) -> Self
pub fn set_image_id(self, value: Option<String>) -> Self
Set image_id
Sourcepub fn set_is_hydrated(self, value: Option<bool>) -> Self
pub fn set_is_hydrated(self, value: Option<bool>) -> Self
Set is_hydrated
Sourcepub fn set_cluster_placement_group_id(self, value: Option<String>) -> Self
pub fn set_cluster_placement_group_id(self, value: Option<String>) -> Self
Set cluster_placement_group_id
Sourcepub fn set_vpus_per_gb(self, value: Option<i64>) -> Self
pub fn set_vpus_per_gb(self, value: Option<i64>) -> Self
Set vpus_per_gb
Sourcepub fn set_lifecycle_state(self, value: BootVolumeLifecycleState) -> Self
pub fn set_lifecycle_state(self, value: BootVolumeLifecycleState) -> Self
Set lifecycle_state
Sourcepub fn set_size_in_gbs(self, value: Option<i64>) -> Self
pub fn set_size_in_gbs(self, value: Option<i64>) -> Self
Set size_in_gbs
Sourcepub fn set_size_in_mbs(self, value: i64) -> Self
pub fn set_size_in_mbs(self, value: i64) -> Self
Set size_in_mbs
Sourcepub fn set_source_details(
self,
value: Option<BootVolumeSourceFromBootVolumeBackupDetails>,
) -> Self
pub fn set_source_details( self, value: Option<BootVolumeSourceFromBootVolumeBackupDetails>, ) -> Self
Set source_details
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Sourcepub fn set_volume_group_id(self, value: Option<String>) -> Self
pub fn set_volume_group_id(self, value: Option<String>) -> Self
Set volume_group_id
Sourcepub fn set_kms_key_id(self, value: Option<String>) -> Self
pub fn set_kms_key_id(self, value: Option<String>) -> Self
Set kms_key_id
Sourcepub fn set_is_auto_tune_enabled(self, value: Option<bool>) -> Self
pub fn set_is_auto_tune_enabled(self, value: Option<bool>) -> Self
Set is_auto_tune_enabled
Sourcepub fn set_auto_tuned_vpus_per_gb(self, value: Option<i64>) -> Self
pub fn set_auto_tuned_vpus_per_gb(self, value: Option<i64>) -> Self
Set auto_tuned_vpus_per_gb
Sourcepub fn set_boot_volume_replicas(
self,
value: Option<Vec<BootVolumeReplicaInfo>>,
) -> Self
pub fn set_boot_volume_replicas( self, value: Option<Vec<BootVolumeReplicaInfo>>, ) -> Self
Set boot_volume_replicas
Sourcepub fn set_autotune_policies(self, value: Option<Vec<AutotunePolicy>>) -> Self
pub fn set_autotune_policies(self, value: Option<Vec<AutotunePolicy>>) -> Self
Set autotune_policies
Set defined_tags (unwraps Option)
Set system_tags (unwraps Option)
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Set freeform_tags (unwraps Option)
Sourcepub fn with_image_id(self, value: impl Into<String>) -> Self
pub fn with_image_id(self, value: impl Into<String>) -> Self
Set image_id (unwraps Option)
Sourcepub fn with_is_hydrated(self, value: bool) -> Self
pub fn with_is_hydrated(self, value: bool) -> Self
Set is_hydrated (unwraps Option)
Sourcepub fn with_cluster_placement_group_id(self, value: impl Into<String>) -> Self
pub fn with_cluster_placement_group_id(self, value: impl Into<String>) -> Self
Set cluster_placement_group_id (unwraps Option)
Sourcepub fn with_vpus_per_gb(self, value: i64) -> Self
pub fn with_vpus_per_gb(self, value: i64) -> Self
Set vpus_per_gb (unwraps Option)
Sourcepub fn with_size_in_gbs(self, value: i64) -> Self
pub fn with_size_in_gbs(self, value: i64) -> Self
Set size_in_gbs (unwraps Option)
Sourcepub fn with_source_details(
self,
value: BootVolumeSourceFromBootVolumeBackupDetails,
) -> Self
pub fn with_source_details( self, value: BootVolumeSourceFromBootVolumeBackupDetails, ) -> Self
Set source_details (unwraps Option)
Sourcepub fn with_volume_group_id(self, value: impl Into<String>) -> Self
pub fn with_volume_group_id(self, value: impl Into<String>) -> Self
Set volume_group_id (unwraps Option)
Sourcepub fn with_kms_key_id(self, value: impl Into<String>) -> Self
pub fn with_kms_key_id(self, value: impl Into<String>) -> Self
Set kms_key_id (unwraps Option)
Sourcepub fn with_is_auto_tune_enabled(self, value: bool) -> Self
pub fn with_is_auto_tune_enabled(self, value: bool) -> Self
Set is_auto_tune_enabled (unwraps Option)
Sourcepub fn with_auto_tuned_vpus_per_gb(self, value: i64) -> Self
pub fn with_auto_tuned_vpus_per_gb(self, value: i64) -> Self
Set auto_tuned_vpus_per_gb (unwraps Option)
Sourcepub fn with_boot_volume_replicas(
self,
value: Vec<BootVolumeReplicaInfo>,
) -> Self
pub fn with_boot_volume_replicas( self, value: Vec<BootVolumeReplicaInfo>, ) -> Self
Set boot_volume_replicas (unwraps Option)
Sourcepub fn with_autotune_policies(self, value: Vec<AutotunePolicy>) -> Self
pub fn with_autotune_policies(self, value: Vec<AutotunePolicy>) -> Self
Set autotune_policies (unwraps Option)