pub struct ComputeHost {Show 26 fields
pub availability_domain: String,
pub compartment_id: String,
pub id: String,
pub fault_domain: String,
pub shape: String,
pub health: ComputeHostHealth,
pub lifecycle_state: ComputeHostLifecycleState,
pub time_created: DateTime<Utc>,
pub time_updated: DateTime<Utc>,
pub hpc_island_id: Option<String>,
pub compute_host_group_id: Option<String>,
pub configuration_state: Option<ConfigurationState>,
pub time_configuration_check: Option<DateTime<Utc>>,
pub configuration_data: Option<ComputeHostConfigurationData>,
pub recycle_details: Option<RecycleDetails>,
pub network_block_id: Option<String>,
pub local_block_id: Option<String>,
pub gpu_memory_fabric_id: Option<String>,
pub instance_id: Option<String>,
pub additional_data: Option<HashMap<String, Value>>,
pub lifecycle_details: Option<HashMap<String, Value>>,
pub capacity_reservation_id: Option<String>,
pub impacted_component_details: Option<HashMap<String, Value>>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub display_name: Option<String>,
pub freeform_tags: Option<HashMap<String, String>>,
}Expand description
The customer facing object includes host details.
Fields
availability_domain: StringThe availability domain of the compute host.
Example: {@code Uocm:US-CHICAGO-1-AD-2}
compartment_id: StringThe OCID for the compartment. This should always be the root compartment.
id: StringThe OCID for the Customer-unique host
fault_domain: StringA fault domain is a grouping of hardware and infrastructure within an availability domain. Each availability domain contains three fault domains. Fault domains let you distribute your instances so that they are not on the same physical hardware within a single availability domain. A hardware failure or Compute hardware maintenance that affects one fault domain does not affect instances in other fault domains.
This field is the Fault domain of the host
shape: StringThe shape of host
health: ComputeHostHealthThe heathy state of the host
lifecycle_state: ComputeHostLifecycleStateThe lifecycle state of the host
time_created: DateTime<Utc>The date and time that the compute host record was created, in the format defined by [RFC3339](https://tools .ietf.org/html/rfc3339).
Example: {@code 2016-08-25T21:10:29.600Z}
time_updated: DateTime<Utc>The date and time that the compute host record was updated, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}
hpc_island_id: Option<String>The OCID for Customer-unique HPC Island
compute_host_group_id: Option<String>The OCID for the Customer-unique host group associated with the Compute Bare Metal Host.
configuration_state: Option<ConfigurationState>Configuration state of the Compute Bare Metal Host.
time_configuration_check: Option<DateTime<Utc>>The date and time that the compute bare metal host configuration check was updated, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}
configuration_data: Option<ComputeHostConfigurationData>recycle_details: Option<RecycleDetails>network_block_id: Option<String>The OCID for Customer-unique Network Block
local_block_id: Option<String>The OCID for Customer-unique Local Block
gpu_memory_fabric_id: Option<String>The OCID for Customer-unique GPU Memory Fabric
instance_id: Option<String>The public OCID for the Virtual Machine or Bare Metal instance
additional_data: Option<HashMap<String, Value>>Additional data that can be exposed to the customer. Will include raw fault codes for strategic customers
lifecycle_details: Option<HashMap<String, Value>>A free-form description detailing why the host is in its current state.
capacity_reservation_id: Option<String>The OCID for the Capacity Reserver that is currently on host
impacted_component_details: Option<HashMap<String, Value>>A list that contains impacted components related to an unhealthy host. An impacted component will be a free-form structure of key values pairs that will provide more or less details based on data tiering
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
Implementations
Sourceimpl ComputeHost
impl ComputeHost
Sourcepub fn new(required: ComputeHostRequired) -> Self
pub fn new(required: ComputeHostRequired) -> Self
Create a new ComputeHost with required fields
Sourcepub fn set_availability_domain(self, value: String) -> Self
pub fn set_availability_domain(self, value: String) -> Self
Set availability_domain
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Sourcepub fn set_fault_domain(self, value: String) -> Self
pub fn set_fault_domain(self, value: String) -> Self
Set fault_domain
Sourcepub fn set_hpc_island_id(self, value: Option<String>) -> Self
pub fn set_hpc_island_id(self, value: Option<String>) -> Self
Set hpc_island_id
Sourcepub fn set_compute_host_group_id(self, value: Option<String>) -> Self
pub fn set_compute_host_group_id(self, value: Option<String>) -> Self
Set compute_host_group_id
Sourcepub fn set_configuration_state(self, value: Option<ConfigurationState>) -> Self
pub fn set_configuration_state(self, value: Option<ConfigurationState>) -> Self
Set configuration_state
Sourcepub fn set_time_configuration_check(self, value: Option<DateTime<Utc>>) -> Self
pub fn set_time_configuration_check(self, value: Option<DateTime<Utc>>) -> Self
Set time_configuration_check
Sourcepub fn set_configuration_data(
self,
value: Option<ComputeHostConfigurationData>,
) -> Self
pub fn set_configuration_data( self, value: Option<ComputeHostConfigurationData>, ) -> Self
Set configuration_data
Sourcepub fn set_recycle_details(self, value: Option<RecycleDetails>) -> Self
pub fn set_recycle_details(self, value: Option<RecycleDetails>) -> Self
Set recycle_details
Sourcepub fn set_network_block_id(self, value: Option<String>) -> Self
pub fn set_network_block_id(self, value: Option<String>) -> Self
Set network_block_id
Sourcepub fn set_local_block_id(self, value: Option<String>) -> Self
pub fn set_local_block_id(self, value: Option<String>) -> Self
Set local_block_id
Sourcepub fn set_gpu_memory_fabric_id(self, value: Option<String>) -> Self
pub fn set_gpu_memory_fabric_id(self, value: Option<String>) -> Self
Set gpu_memory_fabric_id
Sourcepub fn set_instance_id(self, value: Option<String>) -> Self
pub fn set_instance_id(self, value: Option<String>) -> Self
Set instance_id
Sourcepub fn set_health(self, value: ComputeHostHealth) -> Self
pub fn set_health(self, value: ComputeHostHealth) -> Self
Set health
Sourcepub fn set_additional_data(self, value: Option<HashMap<String, Value>>) -> Self
pub fn set_additional_data(self, value: Option<HashMap<String, Value>>) -> Self
Set additional_data
Sourcepub fn set_lifecycle_state(self, value: ComputeHostLifecycleState) -> Self
pub fn set_lifecycle_state(self, value: ComputeHostLifecycleState) -> Self
Set lifecycle_state
Sourcepub fn set_lifecycle_details(
self,
value: Option<HashMap<String, Value>>,
) -> Self
pub fn set_lifecycle_details( self, value: Option<HashMap<String, Value>>, ) -> Self
Set lifecycle_details
Sourcepub fn set_capacity_reservation_id(self, value: Option<String>) -> Self
pub fn set_capacity_reservation_id(self, value: Option<String>) -> Self
Set capacity_reservation_id
Sourcepub fn set_impacted_component_details(
self,
value: Option<HashMap<String, Value>>,
) -> Self
pub fn set_impacted_component_details( self, value: Option<HashMap<String, Value>>, ) -> Self
Set impacted_component_details
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Sourcepub fn set_time_updated(self, value: DateTime<Utc>) -> Self
pub fn set_time_updated(self, value: DateTime<Utc>) -> Self
Set time_updated
Set defined_tags
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Set freeform_tags
Sourcepub fn with_hpc_island_id(self, value: impl Into<String>) -> Self
pub fn with_hpc_island_id(self, value: impl Into<String>) -> Self
Set hpc_island_id (unwraps Option)
Sourcepub fn with_compute_host_group_id(self, value: impl Into<String>) -> Self
pub fn with_compute_host_group_id(self, value: impl Into<String>) -> Self
Set compute_host_group_id (unwraps Option)
Sourcepub fn with_configuration_state(self, value: ConfigurationState) -> Self
pub fn with_configuration_state(self, value: ConfigurationState) -> Self
Set configuration_state (unwraps Option)
Sourcepub fn with_time_configuration_check(self, value: DateTime<Utc>) -> Self
pub fn with_time_configuration_check(self, value: DateTime<Utc>) -> Self
Set time_configuration_check (unwraps Option)
Sourcepub fn with_configuration_data(
self,
value: ComputeHostConfigurationData,
) -> Self
pub fn with_configuration_data( self, value: ComputeHostConfigurationData, ) -> Self
Set configuration_data (unwraps Option)
Sourcepub fn with_recycle_details(self, value: RecycleDetails) -> Self
pub fn with_recycle_details(self, value: RecycleDetails) -> Self
Set recycle_details (unwraps Option)
Sourcepub fn with_network_block_id(self, value: impl Into<String>) -> Self
pub fn with_network_block_id(self, value: impl Into<String>) -> Self
Set network_block_id (unwraps Option)
Sourcepub fn with_local_block_id(self, value: impl Into<String>) -> Self
pub fn with_local_block_id(self, value: impl Into<String>) -> Self
Set local_block_id (unwraps Option)
Sourcepub fn with_gpu_memory_fabric_id(self, value: impl Into<String>) -> Self
pub fn with_gpu_memory_fabric_id(self, value: impl Into<String>) -> Self
Set gpu_memory_fabric_id (unwraps Option)
Sourcepub fn with_instance_id(self, value: impl Into<String>) -> Self
pub fn with_instance_id(self, value: impl Into<String>) -> Self
Set instance_id (unwraps Option)
Sourcepub fn with_additional_data(self, value: HashMap<String, Value>) -> Self
pub fn with_additional_data(self, value: HashMap<String, Value>) -> Self
Set additional_data (unwraps Option)
Sourcepub fn with_lifecycle_details(self, value: HashMap<String, Value>) -> Self
pub fn with_lifecycle_details(self, value: HashMap<String, Value>) -> Self
Set lifecycle_details (unwraps Option)
Sourcepub fn with_capacity_reservation_id(self, value: impl Into<String>) -> Self
pub fn with_capacity_reservation_id(self, value: impl Into<String>) -> Self
Set capacity_reservation_id (unwraps Option)
Sourcepub fn with_impacted_component_details(
self,
value: HashMap<String, Value>,
) -> Self
pub fn with_impacted_component_details( self, value: HashMap<String, Value>, ) -> Self
Set impacted_component_details (unwraps Option)
Set defined_tags (unwraps Option)
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Set freeform_tags (unwraps Option)