pub struct ComputeHostRequired {
pub availability_domain: String,
pub compartment_id: String,
pub id: String,
pub fault_domain: String,
pub shape: String,
pub health: ComputeHostHealth,
pub lifecycle_state: ComputeHostLifecycleState,
pub time_created: DateTime<Utc>,
pub time_updated: DateTime<Utc>,
}Expand description
Required fields for ComputeHost
Fields
availability_domain: StringThe availability domain of the compute host.
Example: {@code Uocm:US-CHICAGO-1-AD-2}
compartment_id: StringThe OCID for the compartment. This should always be the root compartment.
id: StringThe OCID for the Customer-unique host
fault_domain: StringA fault domain is a grouping of hardware and infrastructure within an availability domain. Each availability domain contains three fault domains. Fault domains let you distribute your instances so that they are not on the same physical hardware within a single availability domain. A hardware failure or Compute hardware maintenance that affects one fault domain does not affect instances in other fault domains.
This field is the Fault domain of the host
shape: StringThe shape of host
health: ComputeHostHealthThe heathy state of the host
lifecycle_state: ComputeHostLifecycleStateThe lifecycle state of the host
time_created: DateTime<Utc>The date and time that the compute host record was created, in the format defined by [RFC3339](https://tools .ietf.org/html/rfc3339).
Example: {@code 2016-08-25T21:10:29.600Z}
time_updated: DateTime<Utc>The date and time that the compute host record was updated, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}