pub struct InstanceAgentConfig {
pub is_monitoring_disabled: Option<bool>,
pub is_management_disabled: Option<bool>,
pub are_all_plugins_disabled: Option<bool>,
pub plugins_config: Option<Vec<InstanceAgentPluginConfigDetails>>,
}Expand description
Configuration options for the Oracle Cloud Agent software running on the instance.
Fields
is_monitoring_disabled: Option<bool>Whether Oracle Cloud Agent can gather performance metrics and monitor the instance using the monitoring plugins.
These are the monitoring plugins: Compute Instance Monitoring and Custom Logs Monitoring.
The monitoring plugins are controlled by this parameter and by the per-plugin configuration in the {@code pluginsConfig} object.
- If {@code isMonitoringDisabled} is true, all of the monitoring plugins are disabled, regardless of the per-plugin configuration. - If {@code isMonitoringDisabled} is false, all of the monitoring plugins are enabled. You can optionally disable individual monitoring plugins by providing a value in the {@code pluginsConfig} object.
is_management_disabled: Option<bool>Whether Oracle Cloud Agent can run all the available management plugins.
These are the management plugins: OS Management Service Agent and Compute Instance Run Command.
The management plugins are controlled by this parameter and by the per-plugin configuration in the {@code pluginsConfig} object.
- If {@code isManagementDisabled} is true, all of the management plugins are disabled, regardless of the per-plugin configuration. - If {@code isManagementDisabled} is false, all of the management plugins are enabled. You can optionally disable individual management plugins by providing a value in the {@code pluginsConfig} object.
are_all_plugins_disabled: Option<bool>Whether Oracle Cloud Agent can run all of the available plugins. This includes the management and monitoring plugins.
For more information about the available plugins, see Managing Plugins with Oracle Cloud Agent.
plugins_config: Option<Vec<InstanceAgentPluginConfigDetails>>The configuration of plugins associated with this instance.
Implementations
Sourceimpl InstanceAgentConfig
impl InstanceAgentConfig
Sourcepub fn set_is_monitoring_disabled(self, value: Option<bool>) -> Self
pub fn set_is_monitoring_disabled(self, value: Option<bool>) -> Self
Set is_monitoring_disabled
Sourcepub fn set_is_management_disabled(self, value: Option<bool>) -> Self
pub fn set_is_management_disabled(self, value: Option<bool>) -> Self
Set is_management_disabled
Sourcepub fn set_are_all_plugins_disabled(self, value: Option<bool>) -> Self
pub fn set_are_all_plugins_disabled(self, value: Option<bool>) -> Self
Set are_all_plugins_disabled
Sourcepub fn set_plugins_config(
self,
value: Option<Vec<InstanceAgentPluginConfigDetails>>,
) -> Self
pub fn set_plugins_config( self, value: Option<Vec<InstanceAgentPluginConfigDetails>>, ) -> Self
Set plugins_config
Sourcepub fn with_is_monitoring_disabled(self, value: bool) -> Self
pub fn with_is_monitoring_disabled(self, value: bool) -> Self
Set is_monitoring_disabled (unwraps Option)
Sourcepub fn with_is_management_disabled(self, value: bool) -> Self
pub fn with_is_management_disabled(self, value: bool) -> Self
Set is_management_disabled (unwraps Option)
Sourcepub fn with_are_all_plugins_disabled(self, value: bool) -> Self
pub fn with_are_all_plugins_disabled(self, value: bool) -> Self
Set are_all_plugins_disabled (unwraps Option)
Sourcepub fn with_plugins_config(
self,
value: Vec<InstanceAgentPluginConfigDetails>,
) -> Self
pub fn with_plugins_config( self, value: Vec<InstanceAgentPluginConfigDetails>, ) -> Self
Set plugins_config (unwraps Option)