pub struct InstanceConfiguration {
pub compartment_id: String,
pub id: String,
pub time_created: DateTime<Utc>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub display_name: Option<String>,
pub freeform_tags: Option<HashMap<String, String>>,
pub instance_details: Option<ComputeInstanceOptions>,
pub deferred_fields: Option<Vec<String>>,
}Expand description
An instance configuration is a template that defines the settings to use when creating Compute instances. For more information about instance configurations, see Managing Compute Instances.
Fields
compartment_id: StringThe OCID of the compartment containing the instance configuration.
id: StringThe OCID of the instance configuration.
time_created: DateTime<Utc>The date and time the instance configuration was created, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
instance_details: Option<ComputeInstanceOptions>deferred_fields: Option<Vec<String>>Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the {@link #launchInstanceConfiguration(LaunchInstanceConfigurationRequest) launchInstanceConfiguration} operation.
Implementations
Sourceimpl InstanceConfiguration
impl InstanceConfiguration
Sourcepub fn new(required: InstanceConfigurationRequired) -> Self
pub fn new(required: InstanceConfigurationRequired) -> Self
Create a new InstanceConfiguration with required fields
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Set defined_tags
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Set freeform_tags
Sourcepub fn set_instance_details(self, value: Option<ComputeInstanceOptions>) -> Self
pub fn set_instance_details(self, value: Option<ComputeInstanceOptions>) -> Self
Set instance_details
Sourcepub fn set_deferred_fields(self, value: Option<Vec<String>>) -> Self
pub fn set_deferred_fields(self, value: Option<Vec<String>>) -> Self
Set deferred_fields
Sourcepub fn set_time_created(self, value: DateTime<Utc>) -> Self
pub fn set_time_created(self, value: DateTime<Utc>) -> Self
Set time_created
Set defined_tags (unwraps Option)
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Set freeform_tags (unwraps Option)
Sourcepub fn with_instance_details(self, value: ComputeInstanceOptions) -> Self
pub fn with_instance_details(self, value: ComputeInstanceOptions) -> Self
Set instance_details (unwraps Option)
Sourcepub fn with_deferred_fields(self, value: Vec<String>) -> Self
pub fn with_deferred_fields(self, value: Vec<String>) -> Self
Set deferred_fields (unwraps Option)