pub struct InstanceConsoleConnection {
pub compartment_id: Option<String>,
pub connection_string: Option<String>,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub fingerprint: Option<String>,
pub freeform_tags: Option<HashMap<String, String>>,
pub id: Option<String>,
pub instance_id: Option<String>,
pub lifecycle_state: Option<InstanceConsoleConnectionLifecycleState>,
pub service_host_key_fingerprint: Option<String>,
pub vnc_connection_string: Option<String>,
}Expand description
The {@code InstanceConsoleConnection} API provides you with console access to Compute instances, enabling you to troubleshoot malfunctioning instances remotely.
For more information about instance console connections, see Troubleshooting Instances Using Instance Console Connections.
Fields
compartment_id: Option<String>The OCID of the compartment to contain the console connection.
connection_string: Option<String>The SSH connection string for the console connection.
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
fingerprint: Option<String>The SSH public key’s fingerprint for client authentication to the console connection.
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
id: Option<String>The OCID of the console connection.
instance_id: Option<String>The OCID of the instance the console connection connects to.
lifecycle_state: Option<InstanceConsoleConnectionLifecycleState>The current state of the console connection.
service_host_key_fingerprint: Option<String>The SSH public key’s fingerprint for the console connection service host.
vnc_connection_string: Option<String>The SSH connection string for the SSH tunnel used to connect to the console connection over VNC.
Implementations
Sourceimpl InstanceConsoleConnection
impl InstanceConsoleConnection
Sourcepub fn set_compartment_id(self, value: Option<String>) -> Self
pub fn set_compartment_id(self, value: Option<String>) -> Self
Set compartment_id
Sourcepub fn set_connection_string(self, value: Option<String>) -> Self
pub fn set_connection_string(self, value: Option<String>) -> Self
Set connection_string
Set defined_tags
Sourcepub fn set_fingerprint(self, value: Option<String>) -> Self
pub fn set_fingerprint(self, value: Option<String>) -> Self
Set fingerprint
Set freeform_tags
Sourcepub fn set_instance_id(self, value: Option<String>) -> Self
pub fn set_instance_id(self, value: Option<String>) -> Self
Set instance_id
Sourcepub fn set_lifecycle_state(
self,
value: Option<InstanceConsoleConnectionLifecycleState>,
) -> Self
pub fn set_lifecycle_state( self, value: Option<InstanceConsoleConnectionLifecycleState>, ) -> Self
Set lifecycle_state
Sourcepub fn set_service_host_key_fingerprint(self, value: Option<String>) -> Self
pub fn set_service_host_key_fingerprint(self, value: Option<String>) -> Self
Set service_host_key_fingerprint
Sourcepub fn set_vnc_connection_string(self, value: Option<String>) -> Self
pub fn set_vnc_connection_string(self, value: Option<String>) -> Self
Set vnc_connection_string
Sourcepub fn with_compartment_id(self, value: impl Into<String>) -> Self
pub fn with_compartment_id(self, value: impl Into<String>) -> Self
Set compartment_id (unwraps Option)
Sourcepub fn with_connection_string(self, value: impl Into<String>) -> Self
pub fn with_connection_string(self, value: impl Into<String>) -> Self
Set connection_string (unwraps Option)
Set defined_tags (unwraps Option)
Sourcepub fn with_fingerprint(self, value: impl Into<String>) -> Self
pub fn with_fingerprint(self, value: impl Into<String>) -> Self
Set fingerprint (unwraps Option)
Set freeform_tags (unwraps Option)
Sourcepub fn with_instance_id(self, value: impl Into<String>) -> Self
pub fn with_instance_id(self, value: impl Into<String>) -> Self
Set instance_id (unwraps Option)
Sourcepub fn with_lifecycle_state(
self,
value: InstanceConsoleConnectionLifecycleState,
) -> Self
pub fn with_lifecycle_state( self, value: InstanceConsoleConnectionLifecycleState, ) -> Self
Set lifecycle_state (unwraps Option)
Sourcepub fn with_service_host_key_fingerprint(self, value: impl Into<String>) -> Self
pub fn with_service_host_key_fingerprint(self, value: impl Into<String>) -> Self
Set service_host_key_fingerprint (unwraps Option)
Sourcepub fn with_vnc_connection_string(self, value: impl Into<String>) -> Self
pub fn with_vnc_connection_string(self, value: impl Into<String>) -> Self
Set vnc_connection_string (unwraps Option)