pub struct InstanceMaintenanceEventRequired {
pub id: String,
pub instance_id: String,
pub compartment_id: String,
pub maintenance_category: InstanceMaintenanceEventMaintenanceCategory,
pub maintenance_reason: InstanceMaintenanceEventMaintenanceReason,
pub instance_action: InstanceMaintenanceEventInstanceAction,
pub alternative_resolution_actions: Vec<InstanceMaintenanceEventAlternativeResolutionActions>,
pub time_window_start: DateTime<Utc>,
pub can_reschedule: bool,
pub time_created: DateTime<Utc>,
pub lifecycle_state: InstanceMaintenanceEventLifecycleState,
pub created_by: InstanceMaintenanceEventCreatedBy,
}Expand description
Required fields for InstanceMaintenanceEvent
Fields
id: StringThe OCID of the maintenance event.
instance_id: StringThe OCID of the instance.
compartment_id: StringThe OCID of the compartment that contains the instance.
maintenance_category: InstanceMaintenanceEventMaintenanceCategoryThis indicates the priority and allowed actions for this Maintenance. Higher priority forms of Maintenance have tighter restrictions and may not be rescheduled, while lower priority/severity Maintenance can be rescheduled, deferred, or even cancelled. Please see the Instance Maintenance documentation for details.
maintenance_reason: InstanceMaintenanceEventMaintenanceReasonThis is the reason that Maintenance is being performed. See Instance Maintenance documentation for details.
instance_action: InstanceMaintenanceEventInstanceActionThis is the action that will be performed on the Instance by OCI when the Maintenance begins.
alternative_resolution_actions: Vec<InstanceMaintenanceEventAlternativeResolutionActions>These are alternative actions to the requested instanceAction that can be taken to resolve the Maintenance.
time_window_start: DateTime<Utc>The beginning of the time window when Maintenance is scheduled to begin. The Maintenance will not begin before this time.
can_reschedule: boolIndicates if this MaintenanceEvent is capable of being rescheduled up to the timeHardDueDate.
time_created: DateTime<Utc>The date and time the maintenance event was created, in the format defined by RFC3339. Example: {@code 2016-08-25T21:10:29.600Z}
lifecycle_state: InstanceMaintenanceEventLifecycleStateThe current state of the maintenance event.
created_by: InstanceMaintenanceEventCreatedByThe creator of the maintenance event.