pub struct InstanceShapeConfig {Show 13 fields
pub ocpus: Option<f64>,
pub memory_in_gbs: Option<f64>,
pub baseline_ocpu_utilization: Option<InstanceShapeConfigBaselineOcpuUtilization>,
pub processor_description: Option<String>,
pub networking_bandwidth_in_gbps: Option<f64>,
pub max_vnic_attachments: Option<f64>,
pub gpus: Option<f64>,
pub gpu_description: Option<String>,
pub local_disks: Option<f64>,
pub local_disks_total_size_in_gbs: Option<f64>,
pub local_disk_description: Option<String>,
pub vcpus: Option<f64>,
pub resource_management: Option<InstanceShapeConfigResourceManagement>,
}Expand description
The shape configuration for an instance. The shape configuration determines the resources allocated to an instance.
Fields
ocpus: Option<f64>The total number of OCPUs available to the instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
memory_in_gbs: Option<f64>The total amount of memory available to the instance, in gigabytes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
baseline_ocpu_utilization: Option<InstanceShapeConfigBaselineOcpuUtilization>The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a non-burstable instance, or explicitly specify non-burstable with {@code BASELINE_1_1}.
The following values are supported: - {@code BASELINE_1_8} - baseline usage is 1/8 of an OCPU. - {@code BASELINE_1_2} - baseline usage is 1/2 of an OCPU. - {@code BASELINE_1_1} - baseline usage is the entire OCPU. This represents a non-burstable instance.
processor_description: Option<String>A short description of the instance’s processor (CPU).
networking_bandwidth_in_gbps: Option<f64>The networking bandwidth available to the instance, in gigabits per second. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
max_vnic_attachments: Option<f64>The maximum number of VNIC attachments for the instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
gpus: Option<f64>The number of GPUs available to the instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
gpu_description: Option<String>A short description of the instance’s graphics processing unit (GPU).
If the instance does not have any GPUs, this field is {@code null}.
local_disks: Option<f64>The number of local disks available to the instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
local_disks_total_size_in_gbs: Option<f64>The aggregate size of all local disks, in gigabytes.
If the instance does not have any local disks, this field is {@code null}. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
local_disk_description: Option<String>A short description of the local disks available to this instance.
If the instance does not have any local disks, this field is {@code null}.
vcpus: Option<f64>The total number of VCPUs available to the instance. This can be used instead of OCPUs, in which case the actual number of OCPUs will be calculated based on this value and the actual hardware. This must be a multiple of 2. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
resource_management: Option<InstanceShapeConfigResourceManagement>This field is reserved for internal use.
Implementations
Sourceimpl InstanceShapeConfig
impl InstanceShapeConfig
Sourcepub fn set_memory_in_gbs(self, value: Option<f64>) -> Self
pub fn set_memory_in_gbs(self, value: Option<f64>) -> Self
Set memory_in_gbs
Sourcepub fn set_baseline_ocpu_utilization(
self,
value: Option<InstanceShapeConfigBaselineOcpuUtilization>,
) -> Self
pub fn set_baseline_ocpu_utilization( self, value: Option<InstanceShapeConfigBaselineOcpuUtilization>, ) -> Self
Set baseline_ocpu_utilization
Sourcepub fn set_processor_description(self, value: Option<String>) -> Self
pub fn set_processor_description(self, value: Option<String>) -> Self
Set processor_description
Sourcepub fn set_networking_bandwidth_in_gbps(self, value: Option<f64>) -> Self
pub fn set_networking_bandwidth_in_gbps(self, value: Option<f64>) -> Self
Set networking_bandwidth_in_gbps
Sourcepub fn set_max_vnic_attachments(self, value: Option<f64>) -> Self
pub fn set_max_vnic_attachments(self, value: Option<f64>) -> Self
Set max_vnic_attachments
Sourcepub fn set_gpu_description(self, value: Option<String>) -> Self
pub fn set_gpu_description(self, value: Option<String>) -> Self
Set gpu_description
Sourcepub fn set_local_disks(self, value: Option<f64>) -> Self
pub fn set_local_disks(self, value: Option<f64>) -> Self
Set local_disks
Sourcepub fn set_local_disks_total_size_in_gbs(self, value: Option<f64>) -> Self
pub fn set_local_disks_total_size_in_gbs(self, value: Option<f64>) -> Self
Set local_disks_total_size_in_gbs
Sourcepub fn set_local_disk_description(self, value: Option<String>) -> Self
pub fn set_local_disk_description(self, value: Option<String>) -> Self
Set local_disk_description
Sourcepub fn set_resource_management(
self,
value: Option<InstanceShapeConfigResourceManagement>,
) -> Self
pub fn set_resource_management( self, value: Option<InstanceShapeConfigResourceManagement>, ) -> Self
Set resource_management
Sourcepub fn with_ocpus(self, value: f64) -> Self
pub fn with_ocpus(self, value: f64) -> Self
Set ocpus (unwraps Option)
Sourcepub fn with_memory_in_gbs(self, value: f64) -> Self
pub fn with_memory_in_gbs(self, value: f64) -> Self
Set memory_in_gbs (unwraps Option)
Sourcepub fn with_baseline_ocpu_utilization(
self,
value: InstanceShapeConfigBaselineOcpuUtilization,
) -> Self
pub fn with_baseline_ocpu_utilization( self, value: InstanceShapeConfigBaselineOcpuUtilization, ) -> Self
Set baseline_ocpu_utilization (unwraps Option)
Sourcepub fn with_processor_description(self, value: impl Into<String>) -> Self
pub fn with_processor_description(self, value: impl Into<String>) -> Self
Set processor_description (unwraps Option)
Sourcepub fn with_networking_bandwidth_in_gbps(self, value: f64) -> Self
pub fn with_networking_bandwidth_in_gbps(self, value: f64) -> Self
Set networking_bandwidth_in_gbps (unwraps Option)
Sourcepub fn with_max_vnic_attachments(self, value: f64) -> Self
pub fn with_max_vnic_attachments(self, value: f64) -> Self
Set max_vnic_attachments (unwraps Option)
Sourcepub fn with_gpu_description(self, value: impl Into<String>) -> Self
pub fn with_gpu_description(self, value: impl Into<String>) -> Self
Set gpu_description (unwraps Option)
Sourcepub fn with_local_disks(self, value: f64) -> Self
pub fn with_local_disks(self, value: f64) -> Self
Set local_disks (unwraps Option)
Sourcepub fn with_local_disks_total_size_in_gbs(self, value: f64) -> Self
pub fn with_local_disks_total_size_in_gbs(self, value: f64) -> Self
Set local_disks_total_size_in_gbs (unwraps Option)
Sourcepub fn with_local_disk_description(self, value: impl Into<String>) -> Self
pub fn with_local_disk_description(self, value: impl Into<String>) -> Self
Set local_disk_description (unwraps Option)
Sourcepub fn with_vcpus(self, value: f64) -> Self
pub fn with_vcpus(self, value: f64) -> Self
Set vcpus (unwraps Option)
Sourcepub fn with_resource_management(
self,
value: InstanceShapeConfigResourceManagement,
) -> Self
pub fn with_resource_management( self, value: InstanceShapeConfigResourceManagement, ) -> Self
Set resource_management (unwraps Option)