pub struct RouteTable {
pub compartment_id: String,
pub id: String,
pub lifecycle_state: RouteTableLifecycleState,
pub route_rules: Vec<RouteRule>,
pub vcn_id: String,
pub defined_tags: Option<HashMap<String, HashMap<String, Value>>>,
pub display_name: Option<String>,
pub freeform_tags: Option<HashMap<String, String>>,
pub time_created: Option<DateTime<Utc>>,
}Expand description
A collection of {@code RouteRule} objects, which are used to route packets based on destination IP to a particular network entity. For more information, see Overview of the Networking Service.
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see Getting Started with Policies.
Fields
compartment_id: StringThe OCID of the compartment containing the route table.
id: StringThe route table’s Oracle ID (OCID).
lifecycle_state: RouteTableLifecycleStateThe route table’s current state.
route_rules: Vec<RouteRule>The collection of rules for routing destination IPs to network devices.
vcn_id: StringThe OCID of the VCN the route table list belongs to.
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {@code {"Operations": {"CostCenter": "42"}}}
display_name: Option<String>A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {@code {"Department": "Finance"}}
time_created: Option<DateTime<Utc>>The date and time the route table was created, in the format defined by RFC3339.
Example: {@code 2016-08-25T21:10:29.600Z}
Implementations
Sourceimpl RouteTable
impl RouteTable
Sourcepub fn new(required: RouteTableRequired) -> Self
pub fn new(required: RouteTableRequired) -> Self
Create a new RouteTable with required fields
Sourcepub fn set_compartment_id(self, value: String) -> Self
pub fn set_compartment_id(self, value: String) -> Self
Set compartment_id
Set defined_tags
Sourcepub fn set_display_name(self, value: Option<String>) -> Self
pub fn set_display_name(self, value: Option<String>) -> Self
Set display_name
Set freeform_tags
Sourcepub fn set_lifecycle_state(self, value: RouteTableLifecycleState) -> Self
pub fn set_lifecycle_state(self, value: RouteTableLifecycleState) -> Self
Set lifecycle_state
Sourcepub fn set_route_rules(self, value: Vec<RouteRule>) -> Self
pub fn set_route_rules(self, value: Vec<RouteRule>) -> Self
Set route_rules
Sourcepub fn set_time_created(self, value: Option<DateTime<Utc>>) -> Self
pub fn set_time_created(self, value: Option<DateTime<Utc>>) -> Self
Set time_created
Sourcepub fn set_vcn_id(self, value: String) -> Self
pub fn set_vcn_id(self, value: String) -> Self
Set vcn_id
Set defined_tags (unwraps Option)
Sourcepub fn with_display_name(self, value: impl Into<String>) -> Self
pub fn with_display_name(self, value: impl Into<String>) -> Self
Set display_name (unwraps Option)
Set freeform_tags (unwraps Option)
Sourcepub fn with_time_created(self, value: DateTime<Utc>) -> Self
pub fn with_time_created(self, value: DateTime<Utc>) -> Self
Set time_created (unwraps Option)