pub struct SecurityRule {Show 14 fields
pub direction: SecurityRuleDirection,
pub protocol: String,
pub description: Option<String>,
pub destination: Option<String>,
pub destination_type: Option<SecurityRuleDestinationType>,
pub icmp_options: Option<IcmpOptions>,
pub id: Option<String>,
pub is_stateless: Option<bool>,
pub is_valid: Option<bool>,
pub source: Option<String>,
pub source_type: Option<SecurityRuleSourceType>,
pub tcp_options: Option<TcpOptions>,
pub time_created: Option<DateTime<Utc>>,
pub udp_options: Option<UdpOptions>,
}Expand description
A security rule is one of the items in a {@link NetworkSecurityGroup}. It is a virtual firewall rule for the VNICs in the network security group. A rule can be for either inbound ({@code direction}= INGRESS) or outbound ({@code direction}= EGRESS) IP packets.
Fields
direction: SecurityRuleDirectionDirection of the security rule. Set to {@code EGRESS} for rules to allow outbound IP packets, or {@code INGRESS} for rules to allow inbound IP packets.
protocol: StringThe transport protocol. Specify either {@code all} or an IPv4 protocol number as defined in Protocol Numbers. Options are supported only for ICMP ("1"), TCP ("6"), UDP ("17"), and ICMPv6 ("58").
description: Option<String>An optional description of your choice for the rule.
destination: Option<String>Conceptually, this is the range of IP addresses that a packet originating from the instance can go to.
Allowed values:
An IP address range in CIDR notation. For example: {@code 192.168.1.0/24} or {@code 2001:0db8:0123:45::/56} IPv6 addressing is supported for all commercial and government regions. See IPv6 Addresses.
The {@code cidrBlock} value for a {@link Service}, if you’re setting up a security rule for traffic destined for a particular {@code Service} through a service gateway. For example: {@code oci-phx-objectstorage}.
The OCID of a {@link NetworkSecurityGroup} in the same VCN. The value can be the NSG that the rule belongs to if the rule’s intent is to control traffic between VNICs in the same NSG.
destination_type: Option<SecurityRuleDestinationType>Type of destination for the rule. Required if {@code direction} = {@code EGRESS}.
Allowed values:
{@code CIDR_BLOCK}: If the rule’s {@code destination} is an IP address range in CIDR notation.
{@code SERVICE_CIDR_BLOCK}: If the rule’s {@code destination} is the {@code cidrBlock} value for a {@link Service} (the rule is for traffic destined for a particular {@code Service} through a service gateway).
{@code NETWORK_SECURITY_GROUP}: If the rule’s {@code destination} is the OCID of a {@link NetworkSecurityGroup}.
icmp_options: Option<IcmpOptions>id: Option<String>An Oracle-assigned identifier for the security rule. You specify this ID when you want to update or delete the rule.
Example: {@code 04ABEC}
is_stateless: Option<bool>A stateless rule allows traffic in one direction. Remember to add a corresponding stateless rule in the other direction if you need to support bidirectional traffic. For example, if egress traffic allows TCP destination port 80, there should be an ingress rule to allow TCP source port 80. Defaults to false, which means the rule is stateful and a corresponding rule is not necessary for bidirectional traffic.
is_valid: Option<bool>Whether the rule is valid. The value is {@code True} when the rule is first created. If the rule’s {@code source} or {@code destination} is a network security group, the value changes to {@code False} if that network security group is deleted.
source: Option<String>Conceptually, this is the range of IP addresses that a packet coming into the instance can come from.
Allowed values:
An IP address range in CIDR notation. For example: {@code 192.168.1.0/24} or {@code 2001:0db8:0123:45::/56} IPv6 addressing is supported for all commercial and government regions. See IPv6 Addresses.
The {@code cidrBlock} value for a {@link Service}, if you’re setting up a security rule for traffic coming from a particular {@code Service} through a service gateway. For example: {@code oci-phx-objectstorage}.
The OCID of a {@link NetworkSecurityGroup} in the same VCN. The value can be the NSG that the rule belongs to if the rule’s intent is to control traffic between VNICs in the same NSG.
source_type: Option<SecurityRuleSourceType>Type of source for the rule. Required if {@code direction} = {@code INGRESS}.
{@code CIDR_BLOCK}: If the rule’s {@code source} is an IP address range in CIDR notation.
{@code SERVICE_CIDR_BLOCK}: If the rule’s {@code source} is the {@code cidrBlock} value for a {@link Service} (the rule is for traffic coming from a particular {@code Service} through a service gateway).
{@code NETWORK_SECURITY_GROUP}: If the rule’s {@code source} is the OCID of a {@link NetworkSecurityGroup}.
tcp_options: Option<TcpOptions>time_created: Option<DateTime<Utc>>The date and time the security rule was created. Format defined by RFC3339.
udp_options: Option<UdpOptions>Implementations
Sourceimpl SecurityRule
impl SecurityRule
Sourcepub fn new(required: SecurityRuleRequired) -> Self
pub fn new(required: SecurityRuleRequired) -> Self
Create a new SecurityRule with required fields
Sourcepub fn set_description(self, value: Option<String>) -> Self
pub fn set_description(self, value: Option<String>) -> Self
Set description
Sourcepub fn set_destination(self, value: Option<String>) -> Self
pub fn set_destination(self, value: Option<String>) -> Self
Set destination
Sourcepub fn set_destination_type(
self,
value: Option<SecurityRuleDestinationType>,
) -> Self
pub fn set_destination_type( self, value: Option<SecurityRuleDestinationType>, ) -> Self
Set destination_type
Sourcepub fn set_direction(self, value: SecurityRuleDirection) -> Self
pub fn set_direction(self, value: SecurityRuleDirection) -> Self
Set direction
Sourcepub fn set_icmp_options(self, value: Option<IcmpOptions>) -> Self
pub fn set_icmp_options(self, value: Option<IcmpOptions>) -> Self
Set icmp_options
Sourcepub fn set_is_stateless(self, value: Option<bool>) -> Self
pub fn set_is_stateless(self, value: Option<bool>) -> Self
Set is_stateless
Sourcepub fn set_is_valid(self, value: Option<bool>) -> Self
pub fn set_is_valid(self, value: Option<bool>) -> Self
Set is_valid
Sourcepub fn set_protocol(self, value: String) -> Self
pub fn set_protocol(self, value: String) -> Self
Set protocol
Sourcepub fn set_source(self, value: Option<String>) -> Self
pub fn set_source(self, value: Option<String>) -> Self
Set source
Sourcepub fn set_source_type(self, value: Option<SecurityRuleSourceType>) -> Self
pub fn set_source_type(self, value: Option<SecurityRuleSourceType>) -> Self
Set source_type
Sourcepub fn set_tcp_options(self, value: Option<TcpOptions>) -> Self
pub fn set_tcp_options(self, value: Option<TcpOptions>) -> Self
Set tcp_options
Sourcepub fn set_time_created(self, value: Option<DateTime<Utc>>) -> Self
pub fn set_time_created(self, value: Option<DateTime<Utc>>) -> Self
Set time_created
Sourcepub fn set_udp_options(self, value: Option<UdpOptions>) -> Self
pub fn set_udp_options(self, value: Option<UdpOptions>) -> Self
Set udp_options
Sourcepub fn with_description(self, value: impl Into<String>) -> Self
pub fn with_description(self, value: impl Into<String>) -> Self
Set description (unwraps Option)
Sourcepub fn with_destination(self, value: impl Into<String>) -> Self
pub fn with_destination(self, value: impl Into<String>) -> Self
Set destination (unwraps Option)
Sourcepub fn with_destination_type(self, value: SecurityRuleDestinationType) -> Self
pub fn with_destination_type(self, value: SecurityRuleDestinationType) -> Self
Set destination_type (unwraps Option)
Sourcepub fn with_icmp_options(self, value: IcmpOptions) -> Self
pub fn with_icmp_options(self, value: IcmpOptions) -> Self
Set icmp_options (unwraps Option)
Sourcepub fn with_is_stateless(self, value: bool) -> Self
pub fn with_is_stateless(self, value: bool) -> Self
Set is_stateless (unwraps Option)
Sourcepub fn with_is_valid(self, value: bool) -> Self
pub fn with_is_valid(self, value: bool) -> Self
Set is_valid (unwraps Option)
Sourcepub fn with_source(self, value: impl Into<String>) -> Self
pub fn with_source(self, value: impl Into<String>) -> Self
Set source (unwraps Option)
Sourcepub fn with_source_type(self, value: SecurityRuleSourceType) -> Self
pub fn with_source_type(self, value: SecurityRuleSourceType) -> Self
Set source_type (unwraps Option)
Sourcepub fn with_tcp_options(self, value: TcpOptions) -> Self
pub fn with_tcp_options(self, value: TcpOptions) -> Self
Set tcp_options (unwraps Option)
Sourcepub fn with_time_created(self, value: DateTime<Utc>) -> Self
pub fn with_time_created(self, value: DateTime<Utc>) -> Self
Set time_created (unwraps Option)
Sourcepub fn with_udp_options(self, value: UdpOptions) -> Self
pub fn with_udp_options(self, value: UdpOptions) -> Self
Set udp_options (unwraps Option)