pub struct DeleteVolumeRequest {
pub volume_id: String,
pub if_match: Option<String>,
}Fields
volume_id: StringThe OCID of the volume.
if_match: Option<String>For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.
Implementations
Sourceimpl DeleteVolumeRequest
impl DeleteVolumeRequest
Sourcepub fn new(required: DeleteVolumeRequestRequired) -> Self
pub fn new(required: DeleteVolumeRequestRequired) -> Self
Create a new DeleteVolumeRequest with required fields
Sourcepub fn set_volume_id(self, value: String) -> Self
pub fn set_volume_id(self, value: String) -> Self
Set volume_id
Sourcepub fn set_if_match(self, value: Option<String>) -> Self
pub fn set_if_match(self, value: Option<String>) -> Self
Set if_match
Sourcepub fn with_if_match(self, value: impl Into<String>) -> Self
pub fn with_if_match(self, value: impl Into<String>) -> Self
Set if_match (unwraps Option)