pub struct InstanceActionRequest {
pub instance_id: String,
pub action: String,
pub opc_retry_token: Option<String>,
pub if_match: Option<String>,
pub instance_power_action_details: Option<ResetActionDetails>,
}Fields
instance_id: StringThe OCID of the instance.
action: StringThe action to perform on the instance.
opc_retry_token: Option<String>A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).
if_match: Option<String>For optimistic concurrency control. In the PUT or DELETE call for a resource, set the {@code if-match} parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.
instance_power_action_details: Option<ResetActionDetails>Instance Power Action details
Implementations
Sourceimpl InstanceActionRequest
impl InstanceActionRequest
Sourcepub fn new(required: InstanceActionRequestRequired) -> Self
pub fn new(required: InstanceActionRequestRequired) -> Self
Create a new InstanceActionRequest with required fields
Sourcepub fn set_instance_id(self, value: String) -> Self
pub fn set_instance_id(self, value: String) -> Self
Set instance_id
Sourcepub fn set_action(self, value: String) -> Self
pub fn set_action(self, value: String) -> Self
Set action
Sourcepub fn set_opc_retry_token(self, value: Option<String>) -> Self
pub fn set_opc_retry_token(self, value: Option<String>) -> Self
Set opc_retry_token
Sourcepub fn set_if_match(self, value: Option<String>) -> Self
pub fn set_if_match(self, value: Option<String>) -> Self
Set if_match
Sourcepub fn set_instance_power_action_details(
self,
value: Option<ResetActionDetails>,
) -> Self
pub fn set_instance_power_action_details( self, value: Option<ResetActionDetails>, ) -> Self
Set instance_power_action_details
Sourcepub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
Set opc_retry_token (unwraps Option)
Sourcepub fn with_if_match(self, value: impl Into<String>) -> Self
pub fn with_if_match(self, value: impl Into<String>) -> Self
Set if_match (unwraps Option)
Sourcepub fn with_instance_power_action_details(
self,
value: ResetActionDetails,
) -> Self
pub fn with_instance_power_action_details( self, value: ResetActionDetails, ) -> Self
Set instance_power_action_details (unwraps Option)