pub struct LaunchInstanceRequest {
pub launch_instance_details: LaunchInstanceDetails,
pub opc_retry_token: Option<String>,
}Fields
launch_instance_details: LaunchInstanceDetailsInstance details
opc_retry_token: Option<String>A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations (for example, if a resource has been deleted and purged from the system, then a retry of the original creation request may be rejected).
Implementations
Sourceimpl LaunchInstanceRequest
impl LaunchInstanceRequest
Sourcepub fn new(required: LaunchInstanceRequestRequired) -> Self
pub fn new(required: LaunchInstanceRequestRequired) -> Self
Create a new LaunchInstanceRequest with required fields
Sourcepub fn set_launch_instance_details(self, value: LaunchInstanceDetails) -> Self
pub fn set_launch_instance_details(self, value: LaunchInstanceDetails) -> Self
Set launch_instance_details
Sourcepub fn set_opc_retry_token(self, value: Option<String>) -> Self
pub fn set_opc_retry_token(self, value: Option<String>) -> Self
Set opc_retry_token
Sourcepub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
pub fn with_opc_retry_token(self, value: impl Into<String>) -> Self
Set opc_retry_token (unwraps Option)